# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class PlayReadyAdditionalInformation(object):
    @poscheck_model
    def __init__(self,
                 wrm_header_custom_attributes=None):
        # type: (string_types) -> None

        self._wrm_header_custom_attributes = None
        self.discriminator = None

        if wrm_header_custom_attributes is not None:
            self.wrm_header_custom_attributes = wrm_header_custom_attributes

    @property
    def openapi_types(self):
        types = {
            'wrm_header_custom_attributes': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'wrm_header_custom_attributes': 'wrmHeaderCustomAttributes'
        }
        return attributes

    @property
    def wrm_header_custom_attributes(self):
        # type: () -> string_types
        """Gets the wrm_header_custom_attributes of this PlayReadyAdditionalInformation.

        Custom attributes that you want to add to the WRM header. This string must be valid xml. Some DRM providers require some information in the custom attributes of the msr:pro tag of the DASH manifest, otherwise the content does not play on certain devices.

        :return: The wrm_header_custom_attributes of this PlayReadyAdditionalInformation.
        :rtype: string_types
        """
        return self._wrm_header_custom_attributes

    @wrm_header_custom_attributes.setter
    def wrm_header_custom_attributes(self, wrm_header_custom_attributes):
        # type: (string_types) -> None
        """Sets the wrm_header_custom_attributes of this PlayReadyAdditionalInformation.

        Custom attributes that you want to add to the WRM header. This string must be valid xml. Some DRM providers require some information in the custom attributes of the msr:pro tag of the DASH manifest, otherwise the content does not play on certain devices.

        :param wrm_header_custom_attributes: The wrm_header_custom_attributes of this PlayReadyAdditionalInformation.
        :type: string_types
        """

        if wrm_header_custom_attributes is not None:
            if not isinstance(wrm_header_custom_attributes, string_types):
                raise TypeError("Invalid type for `wrm_header_custom_attributes`, type has to be `string_types`")

        self._wrm_header_custom_attributes = wrm_header_custom_attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayReadyAdditionalInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ProgramDateTimeSource(Enum):
    SYSTEM_CLOCK = "SYSTEM_CLOCK"
    EMBEDDED = "EMBEDDED"



from bitmovin_api_sdk.streams.streams_api import StreamsApi
from bitmovin_api_sdk.streams.video.video_api import VideoApi
from bitmovin_api_sdk.streams.live.live_api import LiveApi
from bitmovin_api_sdk.streams.config.config_api import ConfigApi
from bitmovin_api_sdk.streams.search.search_api import SearchApi
from bitmovin_api_sdk.streams.signing_keys.signing_keys_api import SigningKeysApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class SrtStatisticRecv(object):
    @poscheck_model
    def __init__(self,
                 bytes_=None,
                 bytes_dropped=None,
                 bytes_lost=None,
                 mbit_rate=None,
                 packets=None,
                 packets_belated=None,
                 packets_dropped=None,
                 packets_lost=None,
                 packets_retransmitted=None):
        # type: (int, int, int, float, int, int, int, int, int) -> None

        self._bytes = None
        self._bytes_dropped = None
        self._bytes_lost = None
        self._mbit_rate = None
        self._packets = None
        self._packets_belated = None
        self._packets_dropped = None
        self._packets_lost = None
        self._packets_retransmitted = None
        self.discriminator = None

        if bytes_ is not None:
            self.bytes = bytes_
        if bytes_dropped is not None:
            self.bytes_dropped = bytes_dropped
        if bytes_lost is not None:
            self.bytes_lost = bytes_lost
        if mbit_rate is not None:
            self.mbit_rate = mbit_rate
        if packets is not None:
            self.packets = packets
        if packets_belated is not None:
            self.packets_belated = packets_belated
        if packets_dropped is not None:
            self.packets_dropped = packets_dropped
        if packets_lost is not None:
            self.packets_lost = packets_lost
        if packets_retransmitted is not None:
            self.packets_retransmitted = packets_retransmitted

    @property
    def openapi_types(self):
        types = {
            'bytes': 'int',
            'bytes_dropped': 'int',
            'bytes_lost': 'int',
            'mbit_rate': 'float',
            'packets': 'int',
            'packets_belated': 'int',
            'packets_dropped': 'int',
            'packets_lost': 'int',
            'packets_retransmitted': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'bytes': 'bytes',
            'bytes_dropped': 'bytesDropped',
            'bytes_lost': 'bytesLost',
            'mbit_rate': 'mbitRate',
            'packets': 'packets',
            'packets_belated': 'packetsBelated',
            'packets_dropped': 'packetsDropped',
            'packets_lost': 'packetsLost',
            'packets_retransmitted': 'packetsRetransmitted'
        }
        return attributes

    @property
    def bytes(self):
        # type: () -> int
        """Gets the bytes of this SrtStatisticRecv.


        :return: The bytes of this SrtStatisticRecv.
        :rtype: int
        """
        return self._bytes

    @bytes.setter
    def bytes(self, bytes_):
        # type: (int) -> None
        """Sets the bytes of this SrtStatisticRecv.


        :param bytes_: The bytes of this SrtStatisticRecv.
        :type: int
        """

        if bytes_ is not None:
            if not isinstance(bytes_, int):
                raise TypeError("Invalid type for `bytes`, type has to be `int`")

        self._bytes = bytes_

    @property
    def bytes_dropped(self):
        # type: () -> int
        """Gets the bytes_dropped of this SrtStatisticRecv.


        :return: The bytes_dropped of this SrtStatisticRecv.
        :rtype: int
        """
        return self._bytes_dropped

    @bytes_dropped.setter
    def bytes_dropped(self, bytes_dropped):
        # type: (int) -> None
        """Sets the bytes_dropped of this SrtStatisticRecv.


        :param bytes_dropped: The bytes_dropped of this SrtStatisticRecv.
        :type: int
        """

        if bytes_dropped is not None:
            if not isinstance(bytes_dropped, int):
                raise TypeError("Invalid type for `bytes_dropped`, type has to be `int`")

        self._bytes_dropped = bytes_dropped

    @property
    def bytes_lost(self):
        # type: () -> int
        """Gets the bytes_lost of this SrtStatisticRecv.


        :return: The bytes_lost of this SrtStatisticRecv.
        :rtype: int
        """
        return self._bytes_lost

    @bytes_lost.setter
    def bytes_lost(self, bytes_lost):
        # type: (int) -> None
        """Sets the bytes_lost of this SrtStatisticRecv.


        :param bytes_lost: The bytes_lost of this SrtStatisticRecv.
        :type: int
        """

        if bytes_lost is not None:
            if not isinstance(bytes_lost, int):
                raise TypeError("Invalid type for `bytes_lost`, type has to be `int`")

        self._bytes_lost = bytes_lost

    @property
    def mbit_rate(self):
        # type: () -> float
        """Gets the mbit_rate of this SrtStatisticRecv.


        :return: The mbit_rate of this SrtStatisticRecv.
        :rtype: float
        """
        return self._mbit_rate

    @mbit_rate.setter
    def mbit_rate(self, mbit_rate):
        # type: (float) -> None
        """Sets the mbit_rate of this SrtStatisticRecv.


        :param mbit_rate: The mbit_rate of this SrtStatisticRecv.
        :type: float
        """

        if mbit_rate is not None:
            if not isinstance(mbit_rate, (float, int)):
                raise TypeError("Invalid type for `mbit_rate`, type has to be `float`")

        self._mbit_rate = mbit_rate

    @property
    def packets(self):
        # type: () -> int
        """Gets the packets of this SrtStatisticRecv.


        :return: The packets of this SrtStatisticRecv.
        :rtype: int
        """
        return self._packets

    @packets.setter
    def packets(self, packets):
        # type: (int) -> None
        """Sets the packets of this SrtStatisticRecv.


        :param packets: The packets of this SrtStatisticRecv.
        :type: int
        """

        if packets is not None:
            if not isinstance(packets, int):
                raise TypeError("Invalid type for `packets`, type has to be `int`")

        self._packets = packets

    @property
    def packets_belated(self):
        # type: () -> int
        """Gets the packets_belated of this SrtStatisticRecv.


        :return: The packets_belated of this SrtStatisticRecv.
        :rtype: int
        """
        return self._packets_belated

    @packets_belated.setter
    def packets_belated(self, packets_belated):
        # type: (int) -> None
        """Sets the packets_belated of this SrtStatisticRecv.


        :param packets_belated: The packets_belated of this SrtStatisticRecv.
        :type: int
        """

        if packets_belated is not None:
            if not isinstance(packets_belated, int):
                raise TypeError("Invalid type for `packets_belated`, type has to be `int`")

        self._packets_belated = packets_belated

    @property
    def packets_dropped(self):
        # type: () -> int
        """Gets the packets_dropped of this SrtStatisticRecv.


        :return: The packets_dropped of this SrtStatisticRecv.
        :rtype: int
        """
        return self._packets_dropped

    @packets_dropped.setter
    def packets_dropped(self, packets_dropped):
        # type: (int) -> None
        """Sets the packets_dropped of this SrtStatisticRecv.


        :param packets_dropped: The packets_dropped of this SrtStatisticRecv.
        :type: int
        """

        if packets_dropped is not None:
            if not isinstance(packets_dropped, int):
                raise TypeError("Invalid type for `packets_dropped`, type has to be `int`")

        self._packets_dropped = packets_dropped

    @property
    def packets_lost(self):
        # type: () -> int
        """Gets the packets_lost of this SrtStatisticRecv.


        :return: The packets_lost of this SrtStatisticRecv.
        :rtype: int
        """
        return self._packets_lost

    @packets_lost.setter
    def packets_lost(self, packets_lost):
        # type: (int) -> None
        """Sets the packets_lost of this SrtStatisticRecv.


        :param packets_lost: The packets_lost of this SrtStatisticRecv.
        :type: int
        """

        if packets_lost is not None:
            if not isinstance(packets_lost, int):
                raise TypeError("Invalid type for `packets_lost`, type has to be `int`")

        self._packets_lost = packets_lost

    @property
    def packets_retransmitted(self):
        # type: () -> int
        """Gets the packets_retransmitted of this SrtStatisticRecv.


        :return: The packets_retransmitted of this SrtStatisticRecv.
        :rtype: int
        """
        return self._packets_retransmitted

    @packets_retransmitted.setter
    def packets_retransmitted(self, packets_retransmitted):
        # type: (int) -> None
        """Sets the packets_retransmitted of this SrtStatisticRecv.


        :param packets_retransmitted: The packets_retransmitted of this SrtStatisticRecv.
        :type: int
        """

        if packets_retransmitted is not None:
            if not isinstance(packets_retransmitted, int):
                raise TypeError("Invalid type for `packets_retransmitted`, type has to be `int`")

        self._packets_retransmitted = packets_retransmitted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SrtStatisticRecv):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_digital_center_mix_level import DolbyDigitalCenterMixLevel
from bitmovin_api_sdk.models.dolby_digital_downmixing_preferred_mode import DolbyDigitalDownmixingPreferredMode
from bitmovin_api_sdk.models.dolby_digital_surround_mix_level import DolbyDigitalSurroundMixLevel
import pprint
import six


class DolbyDigitalDownmixing(object):
    @poscheck_model
    def __init__(self,
                 lo_ro_center_mix_level=None,
                 lt_rt_center_mix_level=None,
                 lo_ro_surround_mix_level=None,
                 lt_rt_surround_mix_level=None,
                 preferred_mode=None):
        # type: (DolbyDigitalCenterMixLevel, DolbyDigitalCenterMixLevel, DolbyDigitalSurroundMixLevel, DolbyDigitalSurroundMixLevel, DolbyDigitalDownmixingPreferredMode) -> None

        self._lo_ro_center_mix_level = None
        self._lt_rt_center_mix_level = None
        self._lo_ro_surround_mix_level = None
        self._lt_rt_surround_mix_level = None
        self._preferred_mode = None
        self.discriminator = None

        if lo_ro_center_mix_level is not None:
            self.lo_ro_center_mix_level = lo_ro_center_mix_level
        if lt_rt_center_mix_level is not None:
            self.lt_rt_center_mix_level = lt_rt_center_mix_level
        if lo_ro_surround_mix_level is not None:
            self.lo_ro_surround_mix_level = lo_ro_surround_mix_level
        if lt_rt_surround_mix_level is not None:
            self.lt_rt_surround_mix_level = lt_rt_surround_mix_level
        if preferred_mode is not None:
            self.preferred_mode = preferred_mode

    @property
    def openapi_types(self):
        types = {
            'lo_ro_center_mix_level': 'DolbyDigitalCenterMixLevel',
            'lt_rt_center_mix_level': 'DolbyDigitalCenterMixLevel',
            'lo_ro_surround_mix_level': 'DolbyDigitalSurroundMixLevel',
            'lt_rt_surround_mix_level': 'DolbyDigitalSurroundMixLevel',
            'preferred_mode': 'DolbyDigitalDownmixingPreferredMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'lo_ro_center_mix_level': 'loRoCenterMixLevel',
            'lt_rt_center_mix_level': 'ltRtCenterMixLevel',
            'lo_ro_surround_mix_level': 'loRoSurroundMixLevel',
            'lt_rt_surround_mix_level': 'ltRtSurroundMixLevel',
            'preferred_mode': 'preferredMode'
        }
        return attributes

    @property
    def lo_ro_center_mix_level(self):
        # type: () -> DolbyDigitalCenterMixLevel
        """Gets the lo_ro_center_mix_level of this DolbyDigitalDownmixing.

        The level shift applied to the C channel when adding to the L and R outputs as a result of downmixing to one Lo/Ro output.

        :return: The lo_ro_center_mix_level of this DolbyDigitalDownmixing.
        :rtype: DolbyDigitalCenterMixLevel
        """
        return self._lo_ro_center_mix_level

    @lo_ro_center_mix_level.setter
    def lo_ro_center_mix_level(self, lo_ro_center_mix_level):
        # type: (DolbyDigitalCenterMixLevel) -> None
        """Sets the lo_ro_center_mix_level of this DolbyDigitalDownmixing.

        The level shift applied to the C channel when adding to the L and R outputs as a result of downmixing to one Lo/Ro output.

        :param lo_ro_center_mix_level: The lo_ro_center_mix_level of this DolbyDigitalDownmixing.
        :type: DolbyDigitalCenterMixLevel
        """

        if lo_ro_center_mix_level is not None:
            if not isinstance(lo_ro_center_mix_level, DolbyDigitalCenterMixLevel):
                raise TypeError("Invalid type for `lo_ro_center_mix_level`, type has to be `DolbyDigitalCenterMixLevel`")

        self._lo_ro_center_mix_level = lo_ro_center_mix_level

    @property
    def lt_rt_center_mix_level(self):
        # type: () -> DolbyDigitalCenterMixLevel
        """Gets the lt_rt_center_mix_level of this DolbyDigitalDownmixing.

        The level shift applied to the C channel when adding to the L and R outputs as a result of downmixing to one Lt/Rt output.

        :return: The lt_rt_center_mix_level of this DolbyDigitalDownmixing.
        :rtype: DolbyDigitalCenterMixLevel
        """
        return self._lt_rt_center_mix_level

    @lt_rt_center_mix_level.setter
    def lt_rt_center_mix_level(self, lt_rt_center_mix_level):
        # type: (DolbyDigitalCenterMixLevel) -> None
        """Sets the lt_rt_center_mix_level of this DolbyDigitalDownmixing.

        The level shift applied to the C channel when adding to the L and R outputs as a result of downmixing to one Lt/Rt output.

        :param lt_rt_center_mix_level: The lt_rt_center_mix_level of this DolbyDigitalDownmixing.
        :type: DolbyDigitalCenterMixLevel
        """

        if lt_rt_center_mix_level is not None:
            if not isinstance(lt_rt_center_mix_level, DolbyDigitalCenterMixLevel):
                raise TypeError("Invalid type for `lt_rt_center_mix_level`, type has to be `DolbyDigitalCenterMixLevel`")

        self._lt_rt_center_mix_level = lt_rt_center_mix_level

    @property
    def lo_ro_surround_mix_level(self):
        # type: () -> DolbyDigitalSurroundMixLevel
        """Gets the lo_ro_surround_mix_level of this DolbyDigitalDownmixing.

        The level shift applied to the surround channels when downmixing to one Lo/Ro output.

        :return: The lo_ro_surround_mix_level of this DolbyDigitalDownmixing.
        :rtype: DolbyDigitalSurroundMixLevel
        """
        return self._lo_ro_surround_mix_level

    @lo_ro_surround_mix_level.setter
    def lo_ro_surround_mix_level(self, lo_ro_surround_mix_level):
        # type: (DolbyDigitalSurroundMixLevel) -> None
        """Sets the lo_ro_surround_mix_level of this DolbyDigitalDownmixing.

        The level shift applied to the surround channels when downmixing to one Lo/Ro output.

        :param lo_ro_surround_mix_level: The lo_ro_surround_mix_level of this DolbyDigitalDownmixing.
        :type: DolbyDigitalSurroundMixLevel
        """

        if lo_ro_surround_mix_level is not None:
            if not isinstance(lo_ro_surround_mix_level, DolbyDigitalSurroundMixLevel):
                raise TypeError("Invalid type for `lo_ro_surround_mix_level`, type has to be `DolbyDigitalSurroundMixLevel`")

        self._lo_ro_surround_mix_level = lo_ro_surround_mix_level

    @property
    def lt_rt_surround_mix_level(self):
        # type: () -> DolbyDigitalSurroundMixLevel
        """Gets the lt_rt_surround_mix_level of this DolbyDigitalDownmixing.

        The level shift applied to the surround channels when downmixing to one Lt/Rt output.

        :return: The lt_rt_surround_mix_level of this DolbyDigitalDownmixing.
        :rtype: DolbyDigitalSurroundMixLevel
        """
        return self._lt_rt_surround_mix_level

    @lt_rt_surround_mix_level.setter
    def lt_rt_surround_mix_level(self, lt_rt_surround_mix_level):
        # type: (DolbyDigitalSurroundMixLevel) -> None
        """Sets the lt_rt_surround_mix_level of this DolbyDigitalDownmixing.

        The level shift applied to the surround channels when downmixing to one Lt/Rt output.

        :param lt_rt_surround_mix_level: The lt_rt_surround_mix_level of this DolbyDigitalDownmixing.
        :type: DolbyDigitalSurroundMixLevel
        """

        if lt_rt_surround_mix_level is not None:
            if not isinstance(lt_rt_surround_mix_level, DolbyDigitalSurroundMixLevel):
                raise TypeError("Invalid type for `lt_rt_surround_mix_level`, type has to be `DolbyDigitalSurroundMixLevel`")

        self._lt_rt_surround_mix_level = lt_rt_surround_mix_level

    @property
    def preferred_mode(self):
        # type: () -> DolbyDigitalDownmixingPreferredMode
        """Gets the preferred_mode of this DolbyDigitalDownmixing.


        :return: The preferred_mode of this DolbyDigitalDownmixing.
        :rtype: DolbyDigitalDownmixingPreferredMode
        """
        return self._preferred_mode

    @preferred_mode.setter
    def preferred_mode(self, preferred_mode):
        # type: (DolbyDigitalDownmixingPreferredMode) -> None
        """Sets the preferred_mode of this DolbyDigitalDownmixing.


        :param preferred_mode: The preferred_mode of this DolbyDigitalDownmixing.
        :type: DolbyDigitalDownmixingPreferredMode
        """

        if preferred_mode is not None:
            if not isinstance(preferred_mode, DolbyDigitalDownmixingPreferredMode):
                raise TypeError("Invalid type for `preferred_mode`, type has to be `DolbyDigitalDownmixingPreferredMode`")

        self._preferred_mode = preferred_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyDigitalDownmixing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ProfileH265(Enum):
    MAIN = "main"
    MAIN10 = "main10"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.stream_key_status import StreamKeyStatus
from bitmovin_api_sdk.models.stream_key_type import StreamKeyType
import pprint
import six


class StreamKey(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 value=None,
                 status=None,
                 type_=None,
                 assigned_encoding_id=None,
                 assigned_ingest_point_id=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, StreamKeyStatus, StreamKeyType, string_types, string_types) -> None
        super(StreamKey, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._value = None
        self._status = None
        self._type = None
        self._assigned_encoding_id = None
        self._assigned_ingest_point_id = None
        self.discriminator = None

        if value is not None:
            self.value = value
        if status is not None:
            self.status = status
        if type_ is not None:
            self.type = type_
        if assigned_encoding_id is not None:
            self.assigned_encoding_id = assigned_encoding_id
        if assigned_ingest_point_id is not None:
            self.assigned_ingest_point_id = assigned_ingest_point_id

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(StreamKey, self), 'openapi_types'):
            types = getattr(super(StreamKey, self), 'openapi_types')

        types.update({
            'value': 'string_types',
            'status': 'StreamKeyStatus',
            'type': 'StreamKeyType',
            'assigned_encoding_id': 'string_types',
            'assigned_ingest_point_id': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(StreamKey, self), 'attribute_map'):
            attributes = getattr(super(StreamKey, self), 'attribute_map')

        attributes.update({
            'value': 'value',
            'status': 'status',
            'type': 'type',
            'assigned_encoding_id': 'assignedEncodingId',
            'assigned_ingest_point_id': 'assignedIngestPointId'
        })
        return attributes

    @property
    def value(self):
        # type: () -> string_types
        """Gets the value of this StreamKey.

        Stream key used for live streaming. This stream key is reserved and can be re-used with different live encodings. If this value is not provided, a unique random stream key will be generated. **Important:** This value has to be globally unique. If it is set manually, be sure to use a secure value. If the stream key value is guessed by others your live encoding can be compromised. 

        :return: The value of this StreamKey.
        :rtype: string_types
        """
        return self._value

    @value.setter
    def value(self, value):
        # type: (string_types) -> None
        """Sets the value of this StreamKey.

        Stream key used for live streaming. This stream key is reserved and can be re-used with different live encodings. If this value is not provided, a unique random stream key will be generated. **Important:** This value has to be globally unique. If it is set manually, be sure to use a secure value. If the stream key value is guessed by others your live encoding can be compromised. 

        :param value: The value of this StreamKey.
        :type: string_types
        """

        if value is not None:
            if not isinstance(value, string_types):
                raise TypeError("Invalid type for `value`, type has to be `string_types`")

        self._value = value

    @property
    def status(self):
        # type: () -> StreamKeyStatus
        """Gets the status of this StreamKey.

        Status of the stream key

        :return: The status of this StreamKey.
        :rtype: StreamKeyStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (StreamKeyStatus) -> None
        """Sets the status of this StreamKey.

        Status of the stream key

        :param status: The status of this StreamKey.
        :type: StreamKeyStatus
        """

        if status is not None:
            if not isinstance(status, StreamKeyStatus):
                raise TypeError("Invalid type for `status`, type has to be `StreamKeyStatus`")

        self._status = status

    @property
    def type(self):
        # type: () -> StreamKeyType
        """Gets the type of this StreamKey.

        Type of the stream key

        :return: The type of this StreamKey.
        :rtype: StreamKeyType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (StreamKeyType) -> None
        """Sets the type of this StreamKey.

        Type of the stream key

        :param type_: The type of this StreamKey.
        :type: StreamKeyType
        """

        if type_ is not None:
            if not isinstance(type_, StreamKeyType):
                raise TypeError("Invalid type for `type`, type has to be `StreamKeyType`")

        self._type = type_

    @property
    def assigned_encoding_id(self):
        # type: () -> string_types
        """Gets the assigned_encoding_id of this StreamKey.

        ID of the encoding that is assigned to this stream key. Not set if status is UNASSIGNED

        :return: The assigned_encoding_id of this StreamKey.
        :rtype: string_types
        """
        return self._assigned_encoding_id

    @assigned_encoding_id.setter
    def assigned_encoding_id(self, assigned_encoding_id):
        # type: (string_types) -> None
        """Sets the assigned_encoding_id of this StreamKey.

        ID of the encoding that is assigned to this stream key. Not set if status is UNASSIGNED

        :param assigned_encoding_id: The assigned_encoding_id of this StreamKey.
        :type: string_types
        """

        if assigned_encoding_id is not None:
            if not isinstance(assigned_encoding_id, string_types):
                raise TypeError("Invalid type for `assigned_encoding_id`, type has to be `string_types`")

        self._assigned_encoding_id = assigned_encoding_id

    @property
    def assigned_ingest_point_id(self):
        # type: () -> string_types
        """Gets the assigned_ingest_point_id of this StreamKey.

        ID of the ingest point that is assigned to this stream key. Not set if status is UNASSIGNED

        :return: The assigned_ingest_point_id of this StreamKey.
        :rtype: string_types
        """
        return self._assigned_ingest_point_id

    @assigned_ingest_point_id.setter
    def assigned_ingest_point_id(self, assigned_ingest_point_id):
        # type: (string_types) -> None
        """Sets the assigned_ingest_point_id of this StreamKey.

        ID of the ingest point that is assigned to this stream key. Not set if status is UNASSIGNED

        :param assigned_ingest_point_id: The assigned_ingest_point_id of this StreamKey.
        :type: string_types
        """

        if assigned_ingest_point_id is not None:
            if not isinstance(assigned_ingest_point_id, string_types):
                raise TypeError("Invalid type for `assigned_ingest_point_id`, type has to be `string_types`")

        self._assigned_ingest_point_id = assigned_ingest_point_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(StreamKey, self), "to_dict"):
            result = super(StreamKey, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.configurations.subtitles.imsc.imsc_api import ImscApi
from bitmovin_api_sdk.encoding.configurations.subtitles.imsc.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.subtitles.imsc.imsc_configuration_list_query_params import ImscConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PositionUnit(Enum):
    PIXELS = "PIXELS"
    PERCENTS = "PERCENTS"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.nex_guard_watermarking_strength import NexGuardWatermarkingStrength
from bitmovin_api_sdk.models.nex_guard_watermarking_type import NexGuardWatermarkingType
import pprint
import six


class NexGuardFileMarker(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 license_=None,
                 watermark_type=None,
                 payload=None,
                 preset=None,
                 strength=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, NexGuardWatermarkingType, int, string_types, NexGuardWatermarkingStrength) -> None
        super(NexGuardFileMarker, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._license = None
        self._watermark_type = None
        self._payload = None
        self._preset = None
        self._strength = None
        self.discriminator = None

        if license_ is not None:
            self.license = license_
        if watermark_type is not None:
            self.watermark_type = watermark_type
        if payload is not None:
            self.payload = payload
        if preset is not None:
            self.preset = preset
        if strength is not None:
            self.strength = strength

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(NexGuardFileMarker, self), 'openapi_types'):
            types = getattr(super(NexGuardFileMarker, self), 'openapi_types')

        types.update({
            'license': 'string_types',
            'watermark_type': 'NexGuardWatermarkingType',
            'payload': 'int',
            'preset': 'string_types',
            'strength': 'NexGuardWatermarkingStrength'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(NexGuardFileMarker, self), 'attribute_map'):
            attributes = getattr(super(NexGuardFileMarker, self), 'attribute_map')

        attributes.update({
            'license': 'license',
            'watermark_type': 'watermarkType',
            'payload': 'payload',
            'preset': 'preset',
            'strength': 'strength'
        })
        return attributes

    @property
    def license(self):
        # type: () -> string_types
        """Gets the license of this NexGuardFileMarker.

        Use the base64 license string that Nagra provides you. (required)

        :return: The license of this NexGuardFileMarker.
        :rtype: string_types
        """
        return self._license

    @license.setter
    def license(self, license_):
        # type: (string_types) -> None
        """Sets the license of this NexGuardFileMarker.

        Use the base64 license string that Nagra provides you. (required)

        :param license_: The license of this NexGuardFileMarker.
        :type: string_types
        """

        if license_ is not None:
            if not isinstance(license_, string_types):
                raise TypeError("Invalid type for `license`, type has to be `string_types`")

        self._license = license_

    @property
    def watermark_type(self):
        # type: () -> NexGuardWatermarkingType
        """Gets the watermark_type of this NexGuardFileMarker.

        The type of watermarking to be used: * `OTT` - A/B watermarking (for video streams only) * `DUPLICATED` - Stream duplication to match A/B video streams in CDN delivery (for audio streams only) 

        :return: The watermark_type of this NexGuardFileMarker.
        :rtype: NexGuardWatermarkingType
        """
        return self._watermark_type

    @watermark_type.setter
    def watermark_type(self, watermark_type):
        # type: (NexGuardWatermarkingType) -> None
        """Sets the watermark_type of this NexGuardFileMarker.

        The type of watermarking to be used: * `OTT` - A/B watermarking (for video streams only) * `DUPLICATED` - Stream duplication to match A/B video streams in CDN delivery (for audio streams only) 

        :param watermark_type: The watermark_type of this NexGuardFileMarker.
        :type: NexGuardWatermarkingType
        """

        if watermark_type is not None:
            if not isinstance(watermark_type, NexGuardWatermarkingType):
                raise TypeError("Invalid type for `watermark_type`, type has to be `NexGuardWatermarkingType`")

        self._watermark_type = watermark_type

    @property
    def payload(self):
        # type: () -> int
        """Gets the payload of this NexGuardFileMarker.

        Specify the payload ID that you want to be associated with this output. Valid values vary depending on your Nagra NexGuard forensic watermarking workflow. For PreRelease Content (NGPR), specify an integer from 1 through 4,194,303. You must generate a unique ID for each asset you watermark, and keep a record of th ID. Neither Nagra nor Bitmovin keep track of this for you.

        :return: The payload of this NexGuardFileMarker.
        :rtype: int
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        # type: (int) -> None
        """Sets the payload of this NexGuardFileMarker.

        Specify the payload ID that you want to be associated with this output. Valid values vary depending on your Nagra NexGuard forensic watermarking workflow. For PreRelease Content (NGPR), specify an integer from 1 through 4,194,303. You must generate a unique ID for each asset you watermark, and keep a record of th ID. Neither Nagra nor Bitmovin keep track of this for you.

        :param payload: The payload of this NexGuardFileMarker.
        :type: int
        """

        if payload is not None:
            if not isinstance(payload, int):
                raise TypeError("Invalid type for `payload`, type has to be `int`")

        self._payload = payload

    @property
    def preset(self):
        # type: () -> string_types
        """Gets the preset of this NexGuardFileMarker.

        Enter one of the watermarking preset strings that Nagra provides you.

        :return: The preset of this NexGuardFileMarker.
        :rtype: string_types
        """
        return self._preset

    @preset.setter
    def preset(self, preset):
        # type: (string_types) -> None
        """Sets the preset of this NexGuardFileMarker.

        Enter one of the watermarking preset strings that Nagra provides you.

        :param preset: The preset of this NexGuardFileMarker.
        :type: string_types
        """

        if preset is not None:
            if not isinstance(preset, string_types):
                raise TypeError("Invalid type for `preset`, type has to be `string_types`")

        self._preset = preset

    @property
    def strength(self):
        # type: () -> NexGuardWatermarkingStrength
        """Gets the strength of this NexGuardFileMarker.

        Optional. Ignore this setting unless Nagra support directs you to specify a value. When you don't specify a value here, the Nagra NexGuard library uses its default value.

        :return: The strength of this NexGuardFileMarker.
        :rtype: NexGuardWatermarkingStrength
        """
        return self._strength

    @strength.setter
    def strength(self, strength):
        # type: (NexGuardWatermarkingStrength) -> None
        """Sets the strength of this NexGuardFileMarker.

        Optional. Ignore this setting unless Nagra support directs you to specify a value. When you don't specify a value here, the Nagra NexGuard library uses its default value.

        :param strength: The strength of this NexGuardFileMarker.
        :type: NexGuardWatermarkingStrength
        """

        if strength is not None:
            if not isinstance(strength, NexGuardWatermarkingStrength):
                raise TypeError("Invalid type for `strength`, type has to be `NexGuardWatermarkingStrength`")

        self._strength = strength

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(NexGuardFileMarker, self), "to_dict"):
            result = super(NexGuardFileMarker, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NexGuardFileMarker):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.analytics.exports.exports_api import ExportsApi
from bitmovin_api_sdk.analytics.impressions.impressions_api import ImpressionsApi
from bitmovin_api_sdk.analytics.insights.insights_api import InsightsApi
from bitmovin_api_sdk.analytics.metrics.metrics_api import MetricsApi
from bitmovin_api_sdk.analytics.ads.ads_api import AdsApi
from bitmovin_api_sdk.analytics.queries.queries_api import QueriesApi
from bitmovin_api_sdk.analytics.licenses.licenses_api import LicensesApi
from bitmovin_api_sdk.analytics.virtual_licenses.virtual_licenses_api import VirtualLicensesApi
from bitmovin_api_sdk.analytics.outputs.outputs_api import OutputsApi


class AnalyticsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AnalyticsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.exports = ExportsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.impressions = ImpressionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.insights = InsightsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.metrics = MetricsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ads = AdsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.queries = QueriesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.licenses = LicensesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.virtual_licenses = VirtualLicensesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.outputs = OutputsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



from bitmovin_api_sdk.encoding.infrastructure.gce.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.gce.regions.gce_account_region_settings_list_query_params import GceAccountRegionSettingsListQueryParams



from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.dvb_subtitle.dvb_subtitle_api import DvbSubtitleApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.auto_level_setup import AutoLevelSetup
from bitmovin_api_sdk.models.av1_preset_configuration import Av1PresetConfiguration
from bitmovin_api_sdk.models.color_config import ColorConfig
from bitmovin_api_sdk.models.display_aspect_ratio import DisplayAspectRatio
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.pixel_format import PixelFormat
from bitmovin_api_sdk.models.video_configuration import VideoConfiguration
import pprint
import six


class Av1VideoConfiguration(VideoConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 width=None,
                 height=None,
                 bitrate=None,
                 rate=None,
                 pixel_format=None,
                 color_config=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None,
                 display_aspect_ratio=None,
                 encoding_mode=None,
                 preset_configuration=None,
                 auto_level_setup=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, int, float, PixelFormat, ColorConfig, int, int, DisplayAspectRatio, EncodingMode, Av1PresetConfiguration, AutoLevelSetup) -> None
        super(Av1VideoConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, width=width, height=height, bitrate=bitrate, rate=rate, pixel_format=pixel_format, color_config=color_config, sample_aspect_ratio_numerator=sample_aspect_ratio_numerator, sample_aspect_ratio_denominator=sample_aspect_ratio_denominator, display_aspect_ratio=display_aspect_ratio, encoding_mode=encoding_mode)

        self._preset_configuration = None
        self._auto_level_setup = None
        self.discriminator = None

        if preset_configuration is not None:
            self.preset_configuration = preset_configuration
        if auto_level_setup is not None:
            self.auto_level_setup = auto_level_setup

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Av1VideoConfiguration, self), 'openapi_types'):
            types = getattr(super(Av1VideoConfiguration, self), 'openapi_types')

        types.update({
            'preset_configuration': 'Av1PresetConfiguration',
            'auto_level_setup': 'AutoLevelSetup'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Av1VideoConfiguration, self), 'attribute_map'):
            attributes = getattr(super(Av1VideoConfiguration, self), 'attribute_map')

        attributes.update({
            'preset_configuration': 'presetConfiguration',
            'auto_level_setup': 'autoLevelSetup'
        })
        return attributes

    @property
    def preset_configuration(self):
        # type: () -> Av1PresetConfiguration
        """Gets the preset_configuration of this Av1VideoConfiguration.

        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.

        :return: The preset_configuration of this Av1VideoConfiguration.
        :rtype: Av1PresetConfiguration
        """
        return self._preset_configuration

    @preset_configuration.setter
    def preset_configuration(self, preset_configuration):
        # type: (Av1PresetConfiguration) -> None
        """Sets the preset_configuration of this Av1VideoConfiguration.

        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.

        :param preset_configuration: The preset_configuration of this Av1VideoConfiguration.
        :type: Av1PresetConfiguration
        """

        if preset_configuration is not None:
            if not isinstance(preset_configuration, Av1PresetConfiguration):
                raise TypeError("Invalid type for `preset_configuration`, type has to be `Av1PresetConfiguration`")

        self._preset_configuration = preset_configuration

    @property
    def auto_level_setup(self):
        # type: () -> AutoLevelSetup
        """Gets the auto_level_setup of this Av1VideoConfiguration.

        Enable/disable automatic calculation of level, maxBitrate, and bufsize based on the least level that satisfies maximum property values for picture resolution, frame rate, and bit rate. In the case the target level is set explicitly, the maximum bitrate and buffer size are calculated based on the defined level. Explicitly setting maxBitrate, or bufsize properties will disable the automatic calculation.

        :return: The auto_level_setup of this Av1VideoConfiguration.
        :rtype: AutoLevelSetup
        """
        return self._auto_level_setup

    @auto_level_setup.setter
    def auto_level_setup(self, auto_level_setup):
        # type: (AutoLevelSetup) -> None
        """Sets the auto_level_setup of this Av1VideoConfiguration.

        Enable/disable automatic calculation of level, maxBitrate, and bufsize based on the least level that satisfies maximum property values for picture resolution, frame rate, and bit rate. In the case the target level is set explicitly, the maximum bitrate and buffer size are calculated based on the defined level. Explicitly setting maxBitrate, or bufsize properties will disable the automatic calculation.

        :param auto_level_setup: The auto_level_setup of this Av1VideoConfiguration.
        :type: AutoLevelSetup
        """

        if auto_level_setup is not None:
            if not isinstance(auto_level_setup, AutoLevelSetup):
                raise TypeError("Invalid type for `auto_level_setup`, type has to be `AutoLevelSetup`")

        self._auto_level_setup = auto_level_setup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Av1VideoConfiguration, self), "to_dict"):
            result = super(Av1VideoConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Av1VideoConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.simple_encoding_vod_job_request import SimpleEncodingVodJobRequest
from bitmovin_api_sdk.models.simple_encoding_vod_job_response import SimpleEncodingVodJobResponse
from bitmovin_api_sdk.encoding.simple.jobs.vod.simple_encoding_vod_job_response_list_query_params import SimpleEncodingVodJobResponseListQueryParams


class VodApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(VodApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, simple_encoding_vod_job_request, **kwargs):
        # type: (SimpleEncodingVodJobRequest, dict) -> SimpleEncodingVodJobResponse
        """Create a Simple Encoding VOD Job

        :param simple_encoding_vod_job_request: The Simple Encoding VOD Job to be created.
        :type simple_encoding_vod_job_request: SimpleEncodingVodJobRequest, required
        :return: Created Simple Encoding VOD Job
        :rtype: SimpleEncodingVodJobResponse
        """

        return self.api_client.post(
            '/encoding/simple/jobs/vod',
            simple_encoding_vod_job_request,
            type=SimpleEncodingVodJobResponse,
            **kwargs
        )

    def get(self, simple_encoding_job_id, **kwargs):
        # type: (string_types, dict) -> SimpleEncodingVodJobResponse
        """Simple Encoding VOD Job details

        :param simple_encoding_job_id: Id of the Simple Encoding VOD Job
        :type simple_encoding_job_id: string_types, required
        :return: Simple Encoding VOD Job
        :rtype: SimpleEncodingVodJobResponse
        """

        return self.api_client.get(
            '/encoding/simple/jobs/vod/{simple_encoding_job_id}',
            path_params={'simple_encoding_job_id': simple_encoding_job_id},
            type=SimpleEncodingVodJobResponse,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (SimpleEncodingVodJobResponseListQueryParams, dict) -> SimpleEncodingVodJobResponse
        """List all Simple Encoding VOD Jobs

        :param query_params: Query parameters
        :type query_params: SimpleEncodingVodJobResponseListQueryParams
        :return: List of Simple Encoding VOD Jobs
        :rtype: SimpleEncodingVodJobResponse
        """

        return self.api_client.get(
            '/encoding/simple/jobs/vod',
            query_params=query_params,
            pagination_response=True,
            type=SimpleEncodingVodJobResponse,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.subtitles_media_info import SubtitlesMediaInfo
from bitmovin_api_sdk.encoding.manifests.hls.media.subtitles.subtitles_media_info_list_query_params import SubtitlesMediaInfoListQueryParams


class SubtitlesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SubtitlesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, subtitles_media_info, **kwargs):
        # type: (string_types, SubtitlesMediaInfo, dict) -> SubtitlesMediaInfo
        """Add Subtitles Media

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param subtitles_media_info: The Subtitles Media to be added
        :type subtitles_media_info: SubtitlesMediaInfo, required
        :return: Subtitles media details
        :rtype: SubtitlesMediaInfo
        """

        return self.api_client.post(
            '/encoding/manifests/hls/{manifest_id}/media/subtitles',
            subtitles_media_info,
            path_params={'manifest_id': manifest_id},
            type=SubtitlesMediaInfo,
            **kwargs
        )

    def delete(self, manifest_id, media_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Subtitles Media

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param media_id: Id of the subtitles media.
        :type media_id: string_types, required
        :return: Id of the subtitles media
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/hls/{manifest_id}/media/subtitles/{media_id}',
            path_params={'manifest_id': manifest_id, 'media_id': media_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, media_id, **kwargs):
        # type: (string_types, string_types, dict) -> SubtitlesMediaInfo
        """Subtitles Media Details

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param media_id: Id of the subtitles media.
        :type media_id: string_types, required
        :return: Subtitles media details
        :rtype: SubtitlesMediaInfo
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/media/subtitles/{media_id}',
            path_params={'manifest_id': manifest_id, 'media_id': media_id},
            type=SubtitlesMediaInfo,
            **kwargs
        )

    def list(self, manifest_id, query_params=None, **kwargs):
        # type: (string_types, SubtitlesMediaInfoListQueryParams, dict) -> SubtitlesMediaInfo
        """List all Subtitles Media

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SubtitlesMediaInfoListQueryParams
        :return: Subtitles media
        :rtype: SubtitlesMediaInfo
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/media/subtitles',
            path_params={'manifest_id': manifest_id},
            query_params=query_params,
            pagination_response=True,
            type=SubtitlesMediaInfo,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.simple_encoding_live_job_request import SimpleEncodingLiveJobRequest
from bitmovin_api_sdk.models.simple_encoding_live_job_response import SimpleEncodingLiveJobResponse


class LiveApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LiveApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, simple_encoding_live_job_request, **kwargs):
        # type: (SimpleEncodingLiveJobRequest, dict) -> SimpleEncodingLiveJobResponse
        """Create a Simple Encoding Live Job

        :param simple_encoding_live_job_request: The Simple Encoding Live Job to be created.
        :type simple_encoding_live_job_request: SimpleEncodingLiveJobRequest, required
        :return: Created Simple Encoding Live Job
        :rtype: SimpleEncodingLiveJobResponse
        """

        return self.api_client.post(
            '/encoding/simple/jobs/live',
            simple_encoding_live_job_request,
            type=SimpleEncodingLiveJobResponse,
            **kwargs
        )

    def get(self, simple_encoding_job_id, **kwargs):
        # type: (string_types, dict) -> SimpleEncodingLiveJobResponse
        """Simple Encoding Live Job details

        :param simple_encoding_job_id: Id of the Simple Encoding Live Job
        :type simple_encoding_job_id: string_types, required
        :return: Simple Encoding Live Job
        :rtype: SimpleEncodingLiveJobResponse
        """

        return self.api_client.get(
            '/encoding/simple/jobs/live/{simple_encoding_job_id}',
            path_params={'simple_encoding_job_id': simple_encoding_job_id},
            type=SimpleEncodingLiveJobResponse,
            **kwargs
        )



from bitmovin_api_sdk.notifications.states.states_api import StatesApi
from bitmovin_api_sdk.notifications.states.notification_state_entry_list_query_params import NotificationStateEntryListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyDigitalEvolutionFrameworkControl(Enum):
    ENABLED = "ENABLED"
    DISABLED = "DISABLED"



from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.dvbsub.dvbsub_api import DvbsubApi
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.dvbsub.burn_in_subtitle_dvb_sub_list_query_params import BurnInSubtitleDvbSubListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_query_timeframe import AnalyticsQueryTimeframe
import pprint
import six


class AnalyticsImpressionsQuery(AnalyticsQueryTimeframe):
    @poscheck_model
    def __init__(self,
                 start=None,
                 end=None,
                 license_key=None,
                 filters=None,
                 limit=None):
        # type: (datetime, datetime, string_types, list[AnalyticsAbstractFilter], int) -> None
        super(AnalyticsImpressionsQuery, self).__init__(start=start, end=end)

        self._license_key = None
        self._filters = list()
        self._limit = None
        self.discriminator = None

        if license_key is not None:
            self.license_key = license_key
        if filters is not None:
            self.filters = filters
        if limit is not None:
            self.limit = limit

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AnalyticsImpressionsQuery, self), 'openapi_types'):
            types = getattr(super(AnalyticsImpressionsQuery, self), 'openapi_types')

        types.update({
            'license_key': 'string_types',
            'filters': 'list[AnalyticsAbstractFilter]',
            'limit': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AnalyticsImpressionsQuery, self), 'attribute_map'):
            attributes = getattr(super(AnalyticsImpressionsQuery, self), 'attribute_map')

        attributes.update({
            'license_key': 'licenseKey',
            'filters': 'filters',
            'limit': 'limit'
        })
        return attributes

    @property
    def license_key(self):
        # type: () -> string_types
        """Gets the license_key of this AnalyticsImpressionsQuery.

        Analytics license key (required)

        :return: The license_key of this AnalyticsImpressionsQuery.
        :rtype: string_types
        """
        return self._license_key

    @license_key.setter
    def license_key(self, license_key):
        # type: (string_types) -> None
        """Sets the license_key of this AnalyticsImpressionsQuery.

        Analytics license key (required)

        :param license_key: The license_key of this AnalyticsImpressionsQuery.
        :type: string_types
        """

        if license_key is not None:
            if not isinstance(license_key, string_types):
                raise TypeError("Invalid type for `license_key`, type has to be `string_types`")

        self._license_key = license_key

    @property
    def filters(self):
        # type: () -> list[AnalyticsAbstractFilter]
        """Gets the filters of this AnalyticsImpressionsQuery.

        Analytics Query Filters  Each filter requires 3 properties: name, operator and value.  Valid operators are [IN, EQ, NE, LT, LTE, GT, GTE, CONTAINS, NOTCONTAINS] 

        :return: The filters of this AnalyticsImpressionsQuery.
        :rtype: list[AnalyticsAbstractFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        # type: (list) -> None
        """Sets the filters of this AnalyticsImpressionsQuery.

        Analytics Query Filters  Each filter requires 3 properties: name, operator and value.  Valid operators are [IN, EQ, NE, LT, LTE, GT, GTE, CONTAINS, NOTCONTAINS] 

        :param filters: The filters of this AnalyticsImpressionsQuery.
        :type: list[AnalyticsAbstractFilter]
        """

        if filters is not None:
            if not isinstance(filters, list):
                raise TypeError("Invalid type for `filters`, type has to be `list[AnalyticsAbstractFilter]`")

        self._filters = filters

    @property
    def limit(self):
        # type: () -> int
        """Gets the limit of this AnalyticsImpressionsQuery.

        Number of returned impressions

        :return: The limit of this AnalyticsImpressionsQuery.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        # type: (int) -> None
        """Sets the limit of this AnalyticsImpressionsQuery.

        Number of returned impressions

        :param limit: The limit of this AnalyticsImpressionsQuery.
        :type: int
        """

        if limit is not None:
            if not isinstance(limit, int):
                raise TypeError("Invalid type for `limit`, type has to be `int`")

        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AnalyticsImpressionsQuery, self), "to_dict"):
            result = super(AnalyticsImpressionsQuery, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsImpressionsQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.player_license import PlayerLicense
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.player.licenses.analytics.analytics_api import AnalyticsApi
from bitmovin_api_sdk.player.licenses.domains.domains_api import DomainsApi
from bitmovin_api_sdk.player.licenses.third_party_licensing.third_party_licensing_api import ThirdPartyLicensingApi
from bitmovin_api_sdk.player.licenses.player_license_list_query_params import PlayerLicenseListQueryParams


class LicensesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LicensesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.analytics = AnalyticsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.domains = DomainsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.third_party_licensing = ThirdPartyLicensingApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, player_license, **kwargs):
        # type: (PlayerLicense, dict) -> PlayerLicense
        """Create Player License

        :param player_license: Player License to be created
        :type player_license: PlayerLicense, required
        :return: Created Player license
        :rtype: PlayerLicense
        """

        return self.api_client.post(
            '/player/licenses',
            player_license,
            type=PlayerLicense,
            **kwargs
        )

    def get(self, license_id, **kwargs):
        # type: (string_types, dict) -> PlayerLicense
        """Get License

        :param license_id: ID of the License
        :type license_id: string_types, required
        :return: Id of Player License
        :rtype: PlayerLicense
        """

        return self.api_client.get(
            '/player/licenses/{license_id}',
            path_params={'license_id': license_id},
            type=PlayerLicense,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (PlayerLicenseListQueryParams, dict) -> PlayerLicense
        """List Player Licenses

        :param query_params: Query parameters
        :type query_params: PlayerLicenseListQueryParams
        :return: Service specific result
        :rtype: PlayerLicense
        """

        return self.api_client.get(
            '/player/licenses',
            query_params=query_params,
            pagination_response=True,
            type=PlayerLicense,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.fmp4_api import Fmp4Api
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.fmp4_muxing_list_query_params import Fmp4MuxingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class BillableEncodingFeatureMinutes(object):
    @poscheck_model
    def __init__(self,
                 feature_type=None,
                 encoded_minutes=None,
                 feature_multiplier=None,
                 billable_minutes=None):
        # type: (string_types, float, float, float) -> None

        self._feature_type = None
        self._encoded_minutes = None
        self._feature_multiplier = None
        self._billable_minutes = None
        self.discriminator = None

        if feature_type is not None:
            self.feature_type = feature_type
        if encoded_minutes is not None:
            self.encoded_minutes = encoded_minutes
        if feature_multiplier is not None:
            self.feature_multiplier = feature_multiplier
        if billable_minutes is not None:
            self.billable_minutes = billable_minutes

    @property
    def openapi_types(self):
        types = {
            'feature_type': 'string_types',
            'encoded_minutes': 'float',
            'feature_multiplier': 'float',
            'billable_minutes': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'feature_type': 'featureType',
            'encoded_minutes': 'encodedMinutes',
            'feature_multiplier': 'featureMultiplier',
            'billable_minutes': 'billableMinutes'
        }
        return attributes

    @property
    def feature_type(self):
        # type: () -> string_types
        """Gets the feature_type of this BillableEncodingFeatureMinutes.

        The name of the feature.

        :return: The feature_type of this BillableEncodingFeatureMinutes.
        :rtype: string_types
        """
        return self._feature_type

    @feature_type.setter
    def feature_type(self, feature_type):
        # type: (string_types) -> None
        """Sets the feature_type of this BillableEncodingFeatureMinutes.

        The name of the feature.

        :param feature_type: The feature_type of this BillableEncodingFeatureMinutes.
        :type: string_types
        """

        if feature_type is not None:
            if not isinstance(feature_type, string_types):
                raise TypeError("Invalid type for `feature_type`, type has to be `string_types`")

        self._feature_type = feature_type

    @property
    def encoded_minutes(self):
        # type: () -> float
        """Gets the encoded_minutes of this BillableEncodingFeatureMinutes.

        Encoded minutes related to this feature.

        :return: The encoded_minutes of this BillableEncodingFeatureMinutes.
        :rtype: float
        """
        return self._encoded_minutes

    @encoded_minutes.setter
    def encoded_minutes(self, encoded_minutes):
        # type: (float) -> None
        """Sets the encoded_minutes of this BillableEncodingFeatureMinutes.

        Encoded minutes related to this feature.

        :param encoded_minutes: The encoded_minutes of this BillableEncodingFeatureMinutes.
        :type: float
        """

        if encoded_minutes is not None:
            if not isinstance(encoded_minutes, (float, int)):
                raise TypeError("Invalid type for `encoded_minutes`, type has to be `float`")

        self._encoded_minutes = encoded_minutes

    @property
    def feature_multiplier(self):
        # type: () -> float
        """Gets the feature_multiplier of this BillableEncodingFeatureMinutes.

        The multiplier used for this feature.

        :return: The feature_multiplier of this BillableEncodingFeatureMinutes.
        :rtype: float
        """
        return self._feature_multiplier

    @feature_multiplier.setter
    def feature_multiplier(self, feature_multiplier):
        # type: (float) -> None
        """Sets the feature_multiplier of this BillableEncodingFeatureMinutes.

        The multiplier used for this feature.

        :param feature_multiplier: The feature_multiplier of this BillableEncodingFeatureMinutes.
        :type: float
        """

        if feature_multiplier is not None:
            if not isinstance(feature_multiplier, (float, int)):
                raise TypeError("Invalid type for `feature_multiplier`, type has to be `float`")

        self._feature_multiplier = feature_multiplier

    @property
    def billable_minutes(self):
        # type: () -> float
        """Gets the billable_minutes of this BillableEncodingFeatureMinutes.

        The billable minutes related to this feature.

        :return: The billable_minutes of this BillableEncodingFeatureMinutes.
        :rtype: float
        """
        return self._billable_minutes

    @billable_minutes.setter
    def billable_minutes(self, billable_minutes):
        # type: (float) -> None
        """Sets the billable_minutes of this BillableEncodingFeatureMinutes.

        The billable minutes related to this feature.

        :param billable_minutes: The billable_minutes of this BillableEncodingFeatureMinutes.
        :type: float
        """

        if billable_minutes is not None:
            if not isinstance(billable_minutes, (float, int)):
                raise TypeError("Invalid type for `billable_minutes`, type has to be `float`")

        self._billable_minutes = billable_minutes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillableEncodingFeatureMinutes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.nex_guard_file_marker import NexGuardFileMarker
from bitmovin_api_sdk.models.stream import Stream
import pprint
import six


class HistoryStream(object):
    @poscheck_model
    def __init__(self,
                 stream=None,
                 filters=None,
                 burn_in_subtitle_dvb_subs=None,
                 burn_in_subtitle_srt_subs=None,
                 nex_guard_file_marker=None,
                 scc_captions=None,
                 bifs=None,
                 dolby_vision_metadata=None,
                 thumbnails=None,
                 sprites=None,
                 psnr_metrics=None):
        # type: (Stream, list[StreamFilter], list[BurnInSubtitleDvbSub], list[BurnInSubtitleSrt], NexGuardFileMarker, list[SccCaption], list[Bif], list[DolbyVisionMetadata], list[Thumbnail], list[Sprite], list[PsnrQualityMetric]) -> None

        self._stream = None
        self._filters = list()
        self._burn_in_subtitle_dvb_subs = list()
        self._burn_in_subtitle_srt_subs = list()
        self._nex_guard_file_marker = None
        self._scc_captions = list()
        self._bifs = list()
        self._dolby_vision_metadata = list()
        self._thumbnails = list()
        self._sprites = list()
        self._psnr_metrics = list()
        self.discriminator = None

        if stream is not None:
            self.stream = stream
        if filters is not None:
            self.filters = filters
        if burn_in_subtitle_dvb_subs is not None:
            self.burn_in_subtitle_dvb_subs = burn_in_subtitle_dvb_subs
        if burn_in_subtitle_srt_subs is not None:
            self.burn_in_subtitle_srt_subs = burn_in_subtitle_srt_subs
        if nex_guard_file_marker is not None:
            self.nex_guard_file_marker = nex_guard_file_marker
        if scc_captions is not None:
            self.scc_captions = scc_captions
        if bifs is not None:
            self.bifs = bifs
        if dolby_vision_metadata is not None:
            self.dolby_vision_metadata = dolby_vision_metadata
        if thumbnails is not None:
            self.thumbnails = thumbnails
        if sprites is not None:
            self.sprites = sprites
        if psnr_metrics is not None:
            self.psnr_metrics = psnr_metrics

    @property
    def openapi_types(self):
        types = {
            'stream': 'Stream',
            'filters': 'list[StreamFilter]',
            'burn_in_subtitle_dvb_subs': 'list[BurnInSubtitleDvbSub]',
            'burn_in_subtitle_srt_subs': 'list[BurnInSubtitleSrt]',
            'nex_guard_file_marker': 'NexGuardFileMarker',
            'scc_captions': 'list[SccCaption]',
            'bifs': 'list[Bif]',
            'dolby_vision_metadata': 'list[DolbyVisionMetadata]',
            'thumbnails': 'list[Thumbnail]',
            'sprites': 'list[Sprite]',
            'psnr_metrics': 'list[PsnrQualityMetric]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream': 'stream',
            'filters': 'filters',
            'burn_in_subtitle_dvb_subs': 'burnInSubtitleDvbSubs',
            'burn_in_subtitle_srt_subs': 'burnInSubtitleSrtSubs',
            'nex_guard_file_marker': 'nexGuardFileMarker',
            'scc_captions': 'sccCaptions',
            'bifs': 'bifs',
            'dolby_vision_metadata': 'dolbyVisionMetadata',
            'thumbnails': 'thumbnails',
            'sprites': 'sprites',
            'psnr_metrics': 'psnrMetrics'
        }
        return attributes

    @property
    def stream(self):
        # type: () -> Stream
        """Gets the stream of this HistoryStream.

        Stream

        :return: The stream of this HistoryStream.
        :rtype: Stream
        """
        return self._stream

    @stream.setter
    def stream(self, stream):
        # type: (Stream) -> None
        """Sets the stream of this HistoryStream.

        Stream

        :param stream: The stream of this HistoryStream.
        :type: Stream
        """

        if stream is not None:
            if not isinstance(stream, Stream):
                raise TypeError("Invalid type for `stream`, type has to be `Stream`")

        self._stream = stream

    @property
    def filters(self):
        # type: () -> list[StreamFilter]
        """Gets the filters of this HistoryStream.

        List of stream filter configurations

        :return: The filters of this HistoryStream.
        :rtype: list[StreamFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        # type: (list) -> None
        """Sets the filters of this HistoryStream.

        List of stream filter configurations

        :param filters: The filters of this HistoryStream.
        :type: list[StreamFilter]
        """

        if filters is not None:
            if not isinstance(filters, list):
                raise TypeError("Invalid type for `filters`, type has to be `list[StreamFilter]`")

        self._filters = filters

    @property
    def burn_in_subtitle_dvb_subs(self):
        # type: () -> list[BurnInSubtitleDvbSub]
        """Gets the burn_in_subtitle_dvb_subs of this HistoryStream.

        List of Burn-In DVB-SUB subtitles

        :return: The burn_in_subtitle_dvb_subs of this HistoryStream.
        :rtype: list[BurnInSubtitleDvbSub]
        """
        return self._burn_in_subtitle_dvb_subs

    @burn_in_subtitle_dvb_subs.setter
    def burn_in_subtitle_dvb_subs(self, burn_in_subtitle_dvb_subs):
        # type: (list) -> None
        """Sets the burn_in_subtitle_dvb_subs of this HistoryStream.

        List of Burn-In DVB-SUB subtitles

        :param burn_in_subtitle_dvb_subs: The burn_in_subtitle_dvb_subs of this HistoryStream.
        :type: list[BurnInSubtitleDvbSub]
        """

        if burn_in_subtitle_dvb_subs is not None:
            if not isinstance(burn_in_subtitle_dvb_subs, list):
                raise TypeError("Invalid type for `burn_in_subtitle_dvb_subs`, type has to be `list[BurnInSubtitleDvbSub]`")

        self._burn_in_subtitle_dvb_subs = burn_in_subtitle_dvb_subs

    @property
    def burn_in_subtitle_srt_subs(self):
        # type: () -> list[BurnInSubtitleSrt]
        """Gets the burn_in_subtitle_srt_subs of this HistoryStream.

        List of burn-in SRT configurations

        :return: The burn_in_subtitle_srt_subs of this HistoryStream.
        :rtype: list[BurnInSubtitleSrt]
        """
        return self._burn_in_subtitle_srt_subs

    @burn_in_subtitle_srt_subs.setter
    def burn_in_subtitle_srt_subs(self, burn_in_subtitle_srt_subs):
        # type: (list) -> None
        """Sets the burn_in_subtitle_srt_subs of this HistoryStream.

        List of burn-in SRT configurations

        :param burn_in_subtitle_srt_subs: The burn_in_subtitle_srt_subs of this HistoryStream.
        :type: list[BurnInSubtitleSrt]
        """

        if burn_in_subtitle_srt_subs is not None:
            if not isinstance(burn_in_subtitle_srt_subs, list):
                raise TypeError("Invalid type for `burn_in_subtitle_srt_subs`, type has to be `list[BurnInSubtitleSrt]`")

        self._burn_in_subtitle_srt_subs = burn_in_subtitle_srt_subs

    @property
    def nex_guard_file_marker(self):
        # type: () -> NexGuardFileMarker
        """Gets the nex_guard_file_marker of this HistoryStream.

        Nexguard file marker watermarking configuration

        :return: The nex_guard_file_marker of this HistoryStream.
        :rtype: NexGuardFileMarker
        """
        return self._nex_guard_file_marker

    @nex_guard_file_marker.setter
    def nex_guard_file_marker(self, nex_guard_file_marker):
        # type: (NexGuardFileMarker) -> None
        """Sets the nex_guard_file_marker of this HistoryStream.

        Nexguard file marker watermarking configuration

        :param nex_guard_file_marker: The nex_guard_file_marker of this HistoryStream.
        :type: NexGuardFileMarker
        """

        if nex_guard_file_marker is not None:
            if not isinstance(nex_guard_file_marker, NexGuardFileMarker):
                raise TypeError("Invalid type for `nex_guard_file_marker`, type has to be `NexGuardFileMarker`")

        self._nex_guard_file_marker = nex_guard_file_marker

    @property
    def scc_captions(self):
        # type: () -> list[SccCaption]
        """Gets the scc_captions of this HistoryStream.

        List of caption configurations

        :return: The scc_captions of this HistoryStream.
        :rtype: list[SccCaption]
        """
        return self._scc_captions

    @scc_captions.setter
    def scc_captions(self, scc_captions):
        # type: (list) -> None
        """Sets the scc_captions of this HistoryStream.

        List of caption configurations

        :param scc_captions: The scc_captions of this HistoryStream.
        :type: list[SccCaption]
        """

        if scc_captions is not None:
            if not isinstance(scc_captions, list):
                raise TypeError("Invalid type for `scc_captions`, type has to be `list[SccCaption]`")

        self._scc_captions = scc_captions

    @property
    def bifs(self):
        # type: () -> list[Bif]
        """Gets the bifs of this HistoryStream.

        List of bif configurations

        :return: The bifs of this HistoryStream.
        :rtype: list[Bif]
        """
        return self._bifs

    @bifs.setter
    def bifs(self, bifs):
        # type: (list) -> None
        """Sets the bifs of this HistoryStream.

        List of bif configurations

        :param bifs: The bifs of this HistoryStream.
        :type: list[Bif]
        """

        if bifs is not None:
            if not isinstance(bifs, list):
                raise TypeError("Invalid type for `bifs`, type has to be `list[Bif]`")

        self._bifs = bifs

    @property
    def dolby_vision_metadata(self):
        # type: () -> list[DolbyVisionMetadata]
        """Gets the dolby_vision_metadata of this HistoryStream.

        List of Dolby Vision Metadata configurations

        :return: The dolby_vision_metadata of this HistoryStream.
        :rtype: list[DolbyVisionMetadata]
        """
        return self._dolby_vision_metadata

    @dolby_vision_metadata.setter
    def dolby_vision_metadata(self, dolby_vision_metadata):
        # type: (list) -> None
        """Sets the dolby_vision_metadata of this HistoryStream.

        List of Dolby Vision Metadata configurations

        :param dolby_vision_metadata: The dolby_vision_metadata of this HistoryStream.
        :type: list[DolbyVisionMetadata]
        """

        if dolby_vision_metadata is not None:
            if not isinstance(dolby_vision_metadata, list):
                raise TypeError("Invalid type for `dolby_vision_metadata`, type has to be `list[DolbyVisionMetadata]`")

        self._dolby_vision_metadata = dolby_vision_metadata

    @property
    def thumbnails(self):
        # type: () -> list[Thumbnail]
        """Gets the thumbnails of this HistoryStream.

        List of Thumbnail configurations

        :return: The thumbnails of this HistoryStream.
        :rtype: list[Thumbnail]
        """
        return self._thumbnails

    @thumbnails.setter
    def thumbnails(self, thumbnails):
        # type: (list) -> None
        """Sets the thumbnails of this HistoryStream.

        List of Thumbnail configurations

        :param thumbnails: The thumbnails of this HistoryStream.
        :type: list[Thumbnail]
        """

        if thumbnails is not None:
            if not isinstance(thumbnails, list):
                raise TypeError("Invalid type for `thumbnails`, type has to be `list[Thumbnail]`")

        self._thumbnails = thumbnails

    @property
    def sprites(self):
        # type: () -> list[Sprite]
        """Gets the sprites of this HistoryStream.

        List of Sprite configurations

        :return: The sprites of this HistoryStream.
        :rtype: list[Sprite]
        """
        return self._sprites

    @sprites.setter
    def sprites(self, sprites):
        # type: (list) -> None
        """Sets the sprites of this HistoryStream.

        List of Sprite configurations

        :param sprites: The sprites of this HistoryStream.
        :type: list[Sprite]
        """

        if sprites is not None:
            if not isinstance(sprites, list):
                raise TypeError("Invalid type for `sprites`, type has to be `list[Sprite]`")

        self._sprites = sprites

    @property
    def psnr_metrics(self):
        # type: () -> list[PsnrQualityMetric]
        """Gets the psnr_metrics of this HistoryStream.

        List of PSNR quality metrics

        :return: The psnr_metrics of this HistoryStream.
        :rtype: list[PsnrQualityMetric]
        """
        return self._psnr_metrics

    @psnr_metrics.setter
    def psnr_metrics(self, psnr_metrics):
        # type: (list) -> None
        """Sets the psnr_metrics of this HistoryStream.

        List of PSNR quality metrics

        :param psnr_metrics: The psnr_metrics of this HistoryStream.
        :type: list[PsnrQualityMetric]
        """

        if psnr_metrics is not None:
            if not isinstance(psnr_metrics, list):
                raise TypeError("Invalid type for `psnr_metrics`, type has to be `list[PsnrQualityMetric]`")

        self._psnr_metrics = psnr_metrics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoryStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.input_streams.audio_mix.audio_mix_api import AudioMixApi
from bitmovin_api_sdk.encoding.encodings.input_streams.audio_mix.audio_mix_input_stream_list_query_params import AudioMixInputStreamListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_configuration import AudioConfiguration
from bitmovin_api_sdk.models.dts_x_channel_layout import DtsXChannelLayout
from bitmovin_api_sdk.models.media_config_bitrate import MediaConfigBitrate
from bitmovin_api_sdk.models.ott_loudness_mode import OttLoudnessMode
import pprint
import six


class DtsXAudioConfiguration(AudioConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bitrate=None,
                 rate=None,
                 channel_layout=None,
                 lkfs_value=None,
                 ott_loudness_mode=None,
                 sync_interval=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, float, DtsXChannelLayout, float, OttLoudnessMode, int) -> None
        super(DtsXAudioConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, bitrate=bitrate, rate=rate)

        self._channel_layout = None
        self._lkfs_value = None
        self._ott_loudness_mode = None
        self._sync_interval = None
        self.discriminator = None

        if channel_layout is not None:
            self.channel_layout = channel_layout
        if lkfs_value is not None:
            self.lkfs_value = lkfs_value
        if ott_loudness_mode is not None:
            self.ott_loudness_mode = ott_loudness_mode
        if sync_interval is not None:
            self.sync_interval = sync_interval

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DtsXAudioConfiguration, self), 'openapi_types'):
            types = getattr(super(DtsXAudioConfiguration, self), 'openapi_types')

        types.update({
            'channel_layout': 'DtsXChannelLayout',
            'lkfs_value': 'float',
            'ott_loudness_mode': 'OttLoudnessMode',
            'sync_interval': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DtsXAudioConfiguration, self), 'attribute_map'):
            attributes = getattr(super(DtsXAudioConfiguration, self), 'attribute_map')

        attributes.update({
            'channel_layout': 'channelLayout',
            'lkfs_value': 'lkfsValue',
            'ott_loudness_mode': 'ottLoudnessMode',
            'sync_interval': 'syncInterval'
        })
        return attributes

    @property
    def channel_layout(self):
        # type: () -> DtsXChannelLayout
        """Gets the channel_layout of this DtsXAudioConfiguration.


        :return: The channel_layout of this DtsXAudioConfiguration.
        :rtype: DtsXChannelLayout
        """
        return self._channel_layout

    @channel_layout.setter
    def channel_layout(self, channel_layout):
        # type: (DtsXChannelLayout) -> None
        """Sets the channel_layout of this DtsXAudioConfiguration.


        :param channel_layout: The channel_layout of this DtsXAudioConfiguration.
        :type: DtsXChannelLayout
        """

        if channel_layout is not None:
            if not isinstance(channel_layout, DtsXChannelLayout):
                raise TypeError("Invalid type for `channel_layout`, type has to be `DtsXChannelLayout`")

        self._channel_layout = channel_layout

    @property
    def lkfs_value(self):
        # type: () -> float
        """Gets the lkfs_value of this DtsXAudioConfiguration.

        Loudness relative to full scale (K-weighted).

        :return: The lkfs_value of this DtsXAudioConfiguration.
        :rtype: float
        """
        return self._lkfs_value

    @lkfs_value.setter
    def lkfs_value(self, lkfs_value):
        # type: (float) -> None
        """Sets the lkfs_value of this DtsXAudioConfiguration.

        Loudness relative to full scale (K-weighted).

        :param lkfs_value: The lkfs_value of this DtsXAudioConfiguration.
        :type: float
        """

        if lkfs_value is not None:
            if lkfs_value is not None and lkfs_value > 0:
                raise ValueError("Invalid value for `lkfs_value`, must be a value less than or equal to `0`")
            if lkfs_value is not None and lkfs_value < -40:
                raise ValueError("Invalid value for `lkfs_value`, must be a value greater than or equal to `-40`")
            if not isinstance(lkfs_value, (float, int)):
                raise TypeError("Invalid type for `lkfs_value`, type has to be `float`")

        self._lkfs_value = lkfs_value

    @property
    def ott_loudness_mode(self):
        # type: () -> OttLoudnessMode
        """Gets the ott_loudness_mode of this DtsXAudioConfiguration.


        :return: The ott_loudness_mode of this DtsXAudioConfiguration.
        :rtype: OttLoudnessMode
        """
        return self._ott_loudness_mode

    @ott_loudness_mode.setter
    def ott_loudness_mode(self, ott_loudness_mode):
        # type: (OttLoudnessMode) -> None
        """Sets the ott_loudness_mode of this DtsXAudioConfiguration.


        :param ott_loudness_mode: The ott_loudness_mode of this DtsXAudioConfiguration.
        :type: OttLoudnessMode
        """

        if ott_loudness_mode is not None:
            if not isinstance(ott_loudness_mode, OttLoudnessMode):
                raise TypeError("Invalid type for `ott_loudness_mode`, type has to be `OttLoudnessMode`")

        self._ott_loudness_mode = ott_loudness_mode

    @property
    def sync_interval(self):
        # type: () -> int
        """Gets the sync_interval of this DtsXAudioConfiguration.

        Specifies the sync interval which ranges from 1 to 10

        :return: The sync_interval of this DtsXAudioConfiguration.
        :rtype: int
        """
        return self._sync_interval

    @sync_interval.setter
    def sync_interval(self, sync_interval):
        # type: (int) -> None
        """Sets the sync_interval of this DtsXAudioConfiguration.

        Specifies the sync interval which ranges from 1 to 10

        :param sync_interval: The sync_interval of this DtsXAudioConfiguration.
        :type: int
        """

        if sync_interval is not None:
            if sync_interval is not None and sync_interval > 10:
                raise ValueError("Invalid value for `sync_interval`, must be a value less than or equal to `10`")
            if sync_interval is not None and sync_interval < 1:
                raise ValueError("Invalid value for `sync_interval`, must be a value greater than or equal to `1`")
            if not isinstance(sync_interval, int):
                raise TypeError("Invalid type for `sync_interval`, type has to be `int`")

        self._sync_interval = sync_interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DtsXAudioConfiguration, self), "to_dict"):
            result = super(DtsXAudioConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DtsXAudioConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class InputListQueryParams(object):
    def __init__(self, offset=None, limit=None, name=None, type_=None, sort=None):
        # type: (int, int, string_types, string_types, string_types) -> None
        super(InputListQueryParams, self).__init__()

        self.offset = offset
        self.limit = limit
        self.name = name
        self.type = type_
        self.sort = sort

    @property
    def openapi_types(self):
        types = {
            'offset': 'int',
            'limit': 'int',
            'name': 'string_types',
            'type': 'string_types',
            'sort': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'limit': 'limit',
            'name': 'name',
            'type': 'type',
            'sort': 'sort'
        }

        return attributes



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.broadcast_ts_muxing_information import BroadcastTsMuxingInformation
from bitmovin_api_sdk.models.fmp4_muxing_information import Fmp4MuxingInformation
from bitmovin_api_sdk.models.mp3_muxing_information import Mp3MuxingInformation
from bitmovin_api_sdk.models.mp4_muxing_information import Mp4MuxingInformation
from bitmovin_api_sdk.models.muxing import Muxing
from bitmovin_api_sdk.models.packed_audio_muxing_information import PackedAudioMuxingInformation
from bitmovin_api_sdk.models.progressive_mov_muxing_information import ProgressiveMovMuxingInformation
from bitmovin_api_sdk.models.progressive_ts_muxing_information import ProgressiveTsMuxingInformation
from bitmovin_api_sdk.models.progressive_webm_muxing_information import ProgressiveWebmMuxingInformation
import pprint
import six


class HistoryMuxing(object):
    @poscheck_model
    def __init__(self,
                 muxing=None,
                 drms=None,
                 broadcast_ts_muxing_information=None,
                 fmp4_muxing_information=None,
                 mp3_muxing_information=None,
                 mp4_muxing_information=None,
                 packed_audio_muxing_information=None,
                 progressive_mov_muxing_information=None,
                 progressive_ts_muxing_information=None,
                 progressive_webm_muxing_information=None):
        # type: (Muxing, list[Drm], BroadcastTsMuxingInformation, Fmp4MuxingInformation, Mp3MuxingInformation, Mp4MuxingInformation, PackedAudioMuxingInformation, ProgressiveMovMuxingInformation, ProgressiveTsMuxingInformation, ProgressiveWebmMuxingInformation) -> None

        self._muxing = None
        self._drms = list()
        self._broadcast_ts_muxing_information = None
        self._fmp4_muxing_information = None
        self._mp3_muxing_information = None
        self._mp4_muxing_information = None
        self._packed_audio_muxing_information = None
        self._progressive_mov_muxing_information = None
        self._progressive_ts_muxing_information = None
        self._progressive_webm_muxing_information = None
        self.discriminator = None

        if muxing is not None:
            self.muxing = muxing
        if drms is not None:
            self.drms = drms
        if broadcast_ts_muxing_information is not None:
            self.broadcast_ts_muxing_information = broadcast_ts_muxing_information
        if fmp4_muxing_information is not None:
            self.fmp4_muxing_information = fmp4_muxing_information
        if mp3_muxing_information is not None:
            self.mp3_muxing_information = mp3_muxing_information
        if mp4_muxing_information is not None:
            self.mp4_muxing_information = mp4_muxing_information
        if packed_audio_muxing_information is not None:
            self.packed_audio_muxing_information = packed_audio_muxing_information
        if progressive_mov_muxing_information is not None:
            self.progressive_mov_muxing_information = progressive_mov_muxing_information
        if progressive_ts_muxing_information is not None:
            self.progressive_ts_muxing_information = progressive_ts_muxing_information
        if progressive_webm_muxing_information is not None:
            self.progressive_webm_muxing_information = progressive_webm_muxing_information

    @property
    def openapi_types(self):
        types = {
            'muxing': 'Muxing',
            'drms': 'list[Drm]',
            'broadcast_ts_muxing_information': 'BroadcastTsMuxingInformation',
            'fmp4_muxing_information': 'Fmp4MuxingInformation',
            'mp3_muxing_information': 'Mp3MuxingInformation',
            'mp4_muxing_information': 'Mp4MuxingInformation',
            'packed_audio_muxing_information': 'PackedAudioMuxingInformation',
            'progressive_mov_muxing_information': 'ProgressiveMovMuxingInformation',
            'progressive_ts_muxing_information': 'ProgressiveTsMuxingInformation',
            'progressive_webm_muxing_information': 'ProgressiveWebmMuxingInformation'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'muxing': 'muxing',
            'drms': 'drms',
            'broadcast_ts_muxing_information': 'broadcastTsMuxingInformation',
            'fmp4_muxing_information': 'fmp4MuxingInformation',
            'mp3_muxing_information': 'mp3MuxingInformation',
            'mp4_muxing_information': 'mp4MuxingInformation',
            'packed_audio_muxing_information': 'packedAudioMuxingInformation',
            'progressive_mov_muxing_information': 'progressiveMovMuxingInformation',
            'progressive_ts_muxing_information': 'progressiveTsMuxingInformation',
            'progressive_webm_muxing_information': 'progressiveWebmMuxingInformation'
        }
        return attributes

    @property
    def muxing(self):
        # type: () -> Muxing
        """Gets the muxing of this HistoryMuxing.

        Muxing

        :return: The muxing of this HistoryMuxing.
        :rtype: Muxing
        """
        return self._muxing

    @muxing.setter
    def muxing(self, muxing):
        # type: (Muxing) -> None
        """Sets the muxing of this HistoryMuxing.

        Muxing

        :param muxing: The muxing of this HistoryMuxing.
        :type: Muxing
        """

        if muxing is not None:
            if not isinstance(muxing, Muxing):
                raise TypeError("Invalid type for `muxing`, type has to be `Muxing`")

        self._muxing = muxing

    @property
    def drms(self):
        # type: () -> list[Drm]
        """Gets the drms of this HistoryMuxing.


        :return: The drms of this HistoryMuxing.
        :rtype: list[Drm]
        """
        return self._drms

    @drms.setter
    def drms(self, drms):
        # type: (list) -> None
        """Sets the drms of this HistoryMuxing.


        :param drms: The drms of this HistoryMuxing.
        :type: list[Drm]
        """

        if drms is not None:
            if not isinstance(drms, list):
                raise TypeError("Invalid type for `drms`, type has to be `list[Drm]`")

        self._drms = drms

    @property
    def broadcast_ts_muxing_information(self):
        # type: () -> BroadcastTsMuxingInformation
        """Gets the broadcast_ts_muxing_information of this HistoryMuxing.


        :return: The broadcast_ts_muxing_information of this HistoryMuxing.
        :rtype: BroadcastTsMuxingInformation
        """
        return self._broadcast_ts_muxing_information

    @broadcast_ts_muxing_information.setter
    def broadcast_ts_muxing_information(self, broadcast_ts_muxing_information):
        # type: (BroadcastTsMuxingInformation) -> None
        """Sets the broadcast_ts_muxing_information of this HistoryMuxing.


        :param broadcast_ts_muxing_information: The broadcast_ts_muxing_information of this HistoryMuxing.
        :type: BroadcastTsMuxingInformation
        """

        if broadcast_ts_muxing_information is not None:
            if not isinstance(broadcast_ts_muxing_information, BroadcastTsMuxingInformation):
                raise TypeError("Invalid type for `broadcast_ts_muxing_information`, type has to be `BroadcastTsMuxingInformation`")

        self._broadcast_ts_muxing_information = broadcast_ts_muxing_information

    @property
    def fmp4_muxing_information(self):
        # type: () -> Fmp4MuxingInformation
        """Gets the fmp4_muxing_information of this HistoryMuxing.


        :return: The fmp4_muxing_information of this HistoryMuxing.
        :rtype: Fmp4MuxingInformation
        """
        return self._fmp4_muxing_information

    @fmp4_muxing_information.setter
    def fmp4_muxing_information(self, fmp4_muxing_information):
        # type: (Fmp4MuxingInformation) -> None
        """Sets the fmp4_muxing_information of this HistoryMuxing.


        :param fmp4_muxing_information: The fmp4_muxing_information of this HistoryMuxing.
        :type: Fmp4MuxingInformation
        """

        if fmp4_muxing_information is not None:
            if not isinstance(fmp4_muxing_information, Fmp4MuxingInformation):
                raise TypeError("Invalid type for `fmp4_muxing_information`, type has to be `Fmp4MuxingInformation`")

        self._fmp4_muxing_information = fmp4_muxing_information

    @property
    def mp3_muxing_information(self):
        # type: () -> Mp3MuxingInformation
        """Gets the mp3_muxing_information of this HistoryMuxing.


        :return: The mp3_muxing_information of this HistoryMuxing.
        :rtype: Mp3MuxingInformation
        """
        return self._mp3_muxing_information

    @mp3_muxing_information.setter
    def mp3_muxing_information(self, mp3_muxing_information):
        # type: (Mp3MuxingInformation) -> None
        """Sets the mp3_muxing_information of this HistoryMuxing.


        :param mp3_muxing_information: The mp3_muxing_information of this HistoryMuxing.
        :type: Mp3MuxingInformation
        """

        if mp3_muxing_information is not None:
            if not isinstance(mp3_muxing_information, Mp3MuxingInformation):
                raise TypeError("Invalid type for `mp3_muxing_information`, type has to be `Mp3MuxingInformation`")

        self._mp3_muxing_information = mp3_muxing_information

    @property
    def mp4_muxing_information(self):
        # type: () -> Mp4MuxingInformation
        """Gets the mp4_muxing_information of this HistoryMuxing.


        :return: The mp4_muxing_information of this HistoryMuxing.
        :rtype: Mp4MuxingInformation
        """
        return self._mp4_muxing_information

    @mp4_muxing_information.setter
    def mp4_muxing_information(self, mp4_muxing_information):
        # type: (Mp4MuxingInformation) -> None
        """Sets the mp4_muxing_information of this HistoryMuxing.


        :param mp4_muxing_information: The mp4_muxing_information of this HistoryMuxing.
        :type: Mp4MuxingInformation
        """

        if mp4_muxing_information is not None:
            if not isinstance(mp4_muxing_information, Mp4MuxingInformation):
                raise TypeError("Invalid type for `mp4_muxing_information`, type has to be `Mp4MuxingInformation`")

        self._mp4_muxing_information = mp4_muxing_information

    @property
    def packed_audio_muxing_information(self):
        # type: () -> PackedAudioMuxingInformation
        """Gets the packed_audio_muxing_information of this HistoryMuxing.


        :return: The packed_audio_muxing_information of this HistoryMuxing.
        :rtype: PackedAudioMuxingInformation
        """
        return self._packed_audio_muxing_information

    @packed_audio_muxing_information.setter
    def packed_audio_muxing_information(self, packed_audio_muxing_information):
        # type: (PackedAudioMuxingInformation) -> None
        """Sets the packed_audio_muxing_information of this HistoryMuxing.


        :param packed_audio_muxing_information: The packed_audio_muxing_information of this HistoryMuxing.
        :type: PackedAudioMuxingInformation
        """

        if packed_audio_muxing_information is not None:
            if not isinstance(packed_audio_muxing_information, PackedAudioMuxingInformation):
                raise TypeError("Invalid type for `packed_audio_muxing_information`, type has to be `PackedAudioMuxingInformation`")

        self._packed_audio_muxing_information = packed_audio_muxing_information

    @property
    def progressive_mov_muxing_information(self):
        # type: () -> ProgressiveMovMuxingInformation
        """Gets the progressive_mov_muxing_information of this HistoryMuxing.


        :return: The progressive_mov_muxing_information of this HistoryMuxing.
        :rtype: ProgressiveMovMuxingInformation
        """
        return self._progressive_mov_muxing_information

    @progressive_mov_muxing_information.setter
    def progressive_mov_muxing_information(self, progressive_mov_muxing_information):
        # type: (ProgressiveMovMuxingInformation) -> None
        """Sets the progressive_mov_muxing_information of this HistoryMuxing.


        :param progressive_mov_muxing_information: The progressive_mov_muxing_information of this HistoryMuxing.
        :type: ProgressiveMovMuxingInformation
        """

        if progressive_mov_muxing_information is not None:
            if not isinstance(progressive_mov_muxing_information, ProgressiveMovMuxingInformation):
                raise TypeError("Invalid type for `progressive_mov_muxing_information`, type has to be `ProgressiveMovMuxingInformation`")

        self._progressive_mov_muxing_information = progressive_mov_muxing_information

    @property
    def progressive_ts_muxing_information(self):
        # type: () -> ProgressiveTsMuxingInformation
        """Gets the progressive_ts_muxing_information of this HistoryMuxing.


        :return: The progressive_ts_muxing_information of this HistoryMuxing.
        :rtype: ProgressiveTsMuxingInformation
        """
        return self._progressive_ts_muxing_information

    @progressive_ts_muxing_information.setter
    def progressive_ts_muxing_information(self, progressive_ts_muxing_information):
        # type: (ProgressiveTsMuxingInformation) -> None
        """Sets the progressive_ts_muxing_information of this HistoryMuxing.


        :param progressive_ts_muxing_information: The progressive_ts_muxing_information of this HistoryMuxing.
        :type: ProgressiveTsMuxingInformation
        """

        if progressive_ts_muxing_information is not None:
            if not isinstance(progressive_ts_muxing_information, ProgressiveTsMuxingInformation):
                raise TypeError("Invalid type for `progressive_ts_muxing_information`, type has to be `ProgressiveTsMuxingInformation`")

        self._progressive_ts_muxing_information = progressive_ts_muxing_information

    @property
    def progressive_webm_muxing_information(self):
        # type: () -> ProgressiveWebmMuxingInformation
        """Gets the progressive_webm_muxing_information of this HistoryMuxing.


        :return: The progressive_webm_muxing_information of this HistoryMuxing.
        :rtype: ProgressiveWebmMuxingInformation
        """
        return self._progressive_webm_muxing_information

    @progressive_webm_muxing_information.setter
    def progressive_webm_muxing_information(self, progressive_webm_muxing_information):
        # type: (ProgressiveWebmMuxingInformation) -> None
        """Sets the progressive_webm_muxing_information of this HistoryMuxing.


        :param progressive_webm_muxing_information: The progressive_webm_muxing_information of this HistoryMuxing.
        :type: ProgressiveWebmMuxingInformation
        """

        if progressive_webm_muxing_information is not None:
            if not isinstance(progressive_webm_muxing_information, ProgressiveWebmMuxingInformation):
                raise TypeError("Invalid type for `progressive_webm_muxing_information`, type has to be `ProgressiveWebmMuxingInformation`")

        self._progressive_webm_muxing_information = progressive_webm_muxing_information

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoryMuxing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.aes_encryption_method import AesEncryptionMethod
from bitmovin_api_sdk.models.drm import Drm
import pprint
import six


class AesEncryptionDrm(Drm):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 outputs=None,
                 key=None,
                 iv=None,
                 key_file_uri=None,
                 method=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[EncodingOutput], string_types, string_types, string_types, AesEncryptionMethod) -> None
        super(AesEncryptionDrm, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, outputs=outputs)

        self._key = None
        self._iv = None
        self._key_file_uri = None
        self._method = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if iv is not None:
            self.iv = iv
        if key_file_uri is not None:
            self.key_file_uri = key_file_uri
        if method is not None:
            self.method = method

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AesEncryptionDrm, self), 'openapi_types'):
            types = getattr(super(AesEncryptionDrm, self), 'openapi_types')

        types.update({
            'key': 'string_types',
            'iv': 'string_types',
            'key_file_uri': 'string_types',
            'method': 'AesEncryptionMethod'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AesEncryptionDrm, self), 'attribute_map'):
            attributes = getattr(super(AesEncryptionDrm, self), 'attribute_map')

        attributes.update({
            'key': 'key',
            'iv': 'iv',
            'key_file_uri': 'keyFileUri',
            'method': 'method'
        })
        return attributes

    @property
    def key(self):
        # type: () -> string_types
        """Gets the key of this AesEncryptionDrm.

        16 byte Encryption key, 32 hexadecimal characters (required)

        :return: The key of this AesEncryptionDrm.
        :rtype: string_types
        """
        return self._key

    @key.setter
    def key(self, key):
        # type: (string_types) -> None
        """Sets the key of this AesEncryptionDrm.

        16 byte Encryption key, 32 hexadecimal characters (required)

        :param key: The key of this AesEncryptionDrm.
        :type: string_types
        """

        if key is not None:
            if not isinstance(key, string_types):
                raise TypeError("Invalid type for `key`, type has to be `string_types`")

        self._key = key

    @property
    def iv(self):
        # type: () -> string_types
        """Gets the iv of this AesEncryptionDrm.

        16 byte initialization vector

        :return: The iv of this AesEncryptionDrm.
        :rtype: string_types
        """
        return self._iv

    @iv.setter
    def iv(self, iv):
        # type: (string_types) -> None
        """Sets the iv of this AesEncryptionDrm.

        16 byte initialization vector

        :param iv: The iv of this AesEncryptionDrm.
        :type: string_types
        """

        if iv is not None:
            if not isinstance(iv, string_types):
                raise TypeError("Invalid type for `iv`, type has to be `string_types`")

        self._iv = iv

    @property
    def key_file_uri(self):
        # type: () -> string_types
        """Gets the key_file_uri of this AesEncryptionDrm.

        Path relative to the output for referencing in the manifest. If this value is not set the key file will be written automatically to the output folder.

        :return: The key_file_uri of this AesEncryptionDrm.
        :rtype: string_types
        """
        return self._key_file_uri

    @key_file_uri.setter
    def key_file_uri(self, key_file_uri):
        # type: (string_types) -> None
        """Sets the key_file_uri of this AesEncryptionDrm.

        Path relative to the output for referencing in the manifest. If this value is not set the key file will be written automatically to the output folder.

        :param key_file_uri: The key_file_uri of this AesEncryptionDrm.
        :type: string_types
        """

        if key_file_uri is not None:
            if not isinstance(key_file_uri, string_types):
                raise TypeError("Invalid type for `key_file_uri`, type has to be `string_types`")

        self._key_file_uri = key_file_uri

    @property
    def method(self):
        # type: () -> AesEncryptionMethod
        """Gets the method of this AesEncryptionDrm.


        :return: The method of this AesEncryptionDrm.
        :rtype: AesEncryptionMethod
        """
        return self._method

    @method.setter
    def method(self, method):
        # type: (AesEncryptionMethod) -> None
        """Sets the method of this AesEncryptionDrm.


        :param method: The method of this AesEncryptionDrm.
        :type: AesEncryptionMethod
        """

        if method is not None:
            if not isinstance(method, AesEncryptionMethod):
                raise TypeError("Invalid type for `method`, type has to be `AesEncryptionMethod`")

        self._method = method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AesEncryptionDrm, self), "to_dict"):
            result = super(AesEncryptionDrm, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AesEncryptionDrm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.srt_statistic_link import SrtStatisticLink
from bitmovin_api_sdk.models.srt_statistic_recv import SrtStatisticRecv
from bitmovin_api_sdk.models.srt_statistic_send import SrtStatisticSend
from bitmovin_api_sdk.models.srt_statistic_window import SrtStatisticWindow
import pprint
import six


class SrtStatistics(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 created_at=None,
                 encoding_id=None,
                 srt_input_id=None,
                 srt_input_selected=None,
                 org_id=None,
                 user_id=None,
                 link=None,
                 window=None,
                 recv=None,
                 send=None):
        # type: (string_types, datetime, string_types, string_types, bool, string_types, string_types, SrtStatisticLink, SrtStatisticWindow, SrtStatisticRecv, SrtStatisticSend) -> None

        self._id = None
        self._created_at = None
        self._encoding_id = None
        self._srt_input_id = None
        self._srt_input_selected = None
        self._org_id = None
        self._user_id = None
        self._link = None
        self._window = None
        self._recv = None
        self._send = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if created_at is not None:
            self.created_at = created_at
        if encoding_id is not None:
            self.encoding_id = encoding_id
        if srt_input_id is not None:
            self.srt_input_id = srt_input_id
        if srt_input_selected is not None:
            self.srt_input_selected = srt_input_selected
        if org_id is not None:
            self.org_id = org_id
        if user_id is not None:
            self.user_id = user_id
        if link is not None:
            self.link = link
        if window is not None:
            self.window = window
        if recv is not None:
            self.recv = recv
        if send is not None:
            self.send = send

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'created_at': 'datetime',
            'encoding_id': 'string_types',
            'srt_input_id': 'string_types',
            'srt_input_selected': 'bool',
            'org_id': 'string_types',
            'user_id': 'string_types',
            'link': 'SrtStatisticLink',
            'window': 'SrtStatisticWindow',
            'recv': 'SrtStatisticRecv',
            'send': 'SrtStatisticSend'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'created_at': 'createdAt',
            'encoding_id': 'encodingId',
            'srt_input_id': 'srtInputId',
            'srt_input_selected': 'srtInputSelected',
            'org_id': 'orgId',
            'user_id': 'userId',
            'link': 'link',
            'window': 'window',
            'recv': 'recv',
            'send': 'send'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this SrtStatistics.

        UUID of the statistic event

        :return: The id of this SrtStatistics.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this SrtStatistics.

        UUID of the statistic event

        :param id_: The id of this SrtStatistics.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this SrtStatistics.

        Timestamp when the srt statistics event was created, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The created_at of this SrtStatistics.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this SrtStatistics.

        Timestamp when the srt statistics event was created, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param created_at: The created_at of this SrtStatistics.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this SrtStatistics.

        UUID of an encoding

        :return: The encoding_id of this SrtStatistics.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this SrtStatistics.

        UUID of an encoding

        :param encoding_id: The encoding_id of this SrtStatistics.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def srt_input_id(self):
        # type: () -> string_types
        """Gets the srt_input_id of this SrtStatistics.

        UUID of the SRT input used to capture this statistics

        :return: The srt_input_id of this SrtStatistics.
        :rtype: string_types
        """
        return self._srt_input_id

    @srt_input_id.setter
    def srt_input_id(self, srt_input_id):
        # type: (string_types) -> None
        """Sets the srt_input_id of this SrtStatistics.

        UUID of the SRT input used to capture this statistics

        :param srt_input_id: The srt_input_id of this SrtStatistics.
        :type: string_types
        """

        if srt_input_id is not None:
            if not isinstance(srt_input_id, string_types):
                raise TypeError("Invalid type for `srt_input_id`, type has to be `string_types`")

        self._srt_input_id = srt_input_id

    @property
    def srt_input_selected(self):
        # type: () -> bool
        """Gets the srt_input_selected of this SrtStatistics.

        Whether the SRT input that generated this statistics was selected (i.e. actively used) at the time or not

        :return: The srt_input_selected of this SrtStatistics.
        :rtype: bool
        """
        return self._srt_input_selected

    @srt_input_selected.setter
    def srt_input_selected(self, srt_input_selected):
        # type: (bool) -> None
        """Sets the srt_input_selected of this SrtStatistics.

        Whether the SRT input that generated this statistics was selected (i.e. actively used) at the time or not

        :param srt_input_selected: The srt_input_selected of this SrtStatistics.
        :type: bool
        """

        if srt_input_selected is not None:
            if not isinstance(srt_input_selected, bool):
                raise TypeError("Invalid type for `srt_input_selected`, type has to be `bool`")

        self._srt_input_selected = srt_input_selected

    @property
    def org_id(self):
        # type: () -> string_types
        """Gets the org_id of this SrtStatistics.

        UUID of the associated organization

        :return: The org_id of this SrtStatistics.
        :rtype: string_types
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        # type: (string_types) -> None
        """Sets the org_id of this SrtStatistics.

        UUID of the associated organization

        :param org_id: The org_id of this SrtStatistics.
        :type: string_types
        """

        if org_id is not None:
            if not isinstance(org_id, string_types):
                raise TypeError("Invalid type for `org_id`, type has to be `string_types`")

        self._org_id = org_id

    @property
    def user_id(self):
        # type: () -> string_types
        """Gets the user_id of this SrtStatistics.

        UUID of the associated api-user

        :return: The user_id of this SrtStatistics.
        :rtype: string_types
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        # type: (string_types) -> None
        """Sets the user_id of this SrtStatistics.

        UUID of the associated api-user

        :param user_id: The user_id of this SrtStatistics.
        :type: string_types
        """

        if user_id is not None:
            if not isinstance(user_id, string_types):
                raise TypeError("Invalid type for `user_id`, type has to be `string_types`")

        self._user_id = user_id

    @property
    def link(self):
        # type: () -> SrtStatisticLink
        """Gets the link of this SrtStatistics.


        :return: The link of this SrtStatistics.
        :rtype: SrtStatisticLink
        """
        return self._link

    @link.setter
    def link(self, link):
        # type: (SrtStatisticLink) -> None
        """Sets the link of this SrtStatistics.


        :param link: The link of this SrtStatistics.
        :type: SrtStatisticLink
        """

        if link is not None:
            if not isinstance(link, SrtStatisticLink):
                raise TypeError("Invalid type for `link`, type has to be `SrtStatisticLink`")

        self._link = link

    @property
    def window(self):
        # type: () -> SrtStatisticWindow
        """Gets the window of this SrtStatistics.


        :return: The window of this SrtStatistics.
        :rtype: SrtStatisticWindow
        """
        return self._window

    @window.setter
    def window(self, window):
        # type: (SrtStatisticWindow) -> None
        """Sets the window of this SrtStatistics.


        :param window: The window of this SrtStatistics.
        :type: SrtStatisticWindow
        """

        if window is not None:
            if not isinstance(window, SrtStatisticWindow):
                raise TypeError("Invalid type for `window`, type has to be `SrtStatisticWindow`")

        self._window = window

    @property
    def recv(self):
        # type: () -> SrtStatisticRecv
        """Gets the recv of this SrtStatistics.


        :return: The recv of this SrtStatistics.
        :rtype: SrtStatisticRecv
        """
        return self._recv

    @recv.setter
    def recv(self, recv):
        # type: (SrtStatisticRecv) -> None
        """Sets the recv of this SrtStatistics.


        :param recv: The recv of this SrtStatistics.
        :type: SrtStatisticRecv
        """

        if recv is not None:
            if not isinstance(recv, SrtStatisticRecv):
                raise TypeError("Invalid type for `recv`, type has to be `SrtStatisticRecv`")

        self._recv = recv

    @property
    def send(self):
        # type: () -> SrtStatisticSend
        """Gets the send of this SrtStatistics.


        :return: The send of this SrtStatistics.
        :rtype: SrtStatisticSend
        """
        return self._send

    @send.setter
    def send(self, send):
        # type: (SrtStatisticSend) -> None
        """Sets the send of this SrtStatistics.


        :param send: The send of this SrtStatistics.
        :type: SrtStatisticSend
        """

        if send is not None:
            if not isinstance(send, SrtStatisticSend):
                raise TypeError("Invalid type for `send`, type has to be `SrtStatisticSend`")

        self._send = send

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SrtStatistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LiveEncodingEventName(Enum):
    FIRST_CONNECT = "FIRST_CONNECT"
    DISCONNECT = "DISCONNECT"
    RECONNECT = "RECONNECT"
    RESYNCING = "RESYNCING"
    IDLE = "IDLE"
    ERROR = "ERROR"



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.progressive_webm.progressive_webm_api import ProgressiveWebmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.progressive_webm.dash_progressive_webm_representation_list_query_params import DashProgressiveWebmRepresentationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input import Input
import pprint
import six


class FtpInput(Input):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 host=None,
                 port=None,
                 passive=None,
                 username=None,
                 password=None,
                 remote_verification_enabled=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, int, bool, string_types, string_types, bool) -> None
        super(FtpInput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._host = None
        self._port = None
        self._passive = None
        self._username = None
        self._password = None
        self._remote_verification_enabled = None
        self.discriminator = None

        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if passive is not None:
            self.passive = passive
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if remote_verification_enabled is not None:
            self.remote_verification_enabled = remote_verification_enabled

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(FtpInput, self), 'openapi_types'):
            types = getattr(super(FtpInput, self), 'openapi_types')

        types.update({
            'host': 'string_types',
            'port': 'int',
            'passive': 'bool',
            'username': 'string_types',
            'password': 'string_types',
            'remote_verification_enabled': 'bool'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(FtpInput, self), 'attribute_map'):
            attributes = getattr(super(FtpInput, self), 'attribute_map')

        attributes.update({
            'host': 'host',
            'port': 'port',
            'passive': 'passive',
            'username': 'username',
            'password': 'password',
            'remote_verification_enabled': 'remoteVerificationEnabled'
        })
        return attributes

    @property
    def host(self):
        # type: () -> string_types
        """Gets the host of this FtpInput.

        Host URL or IP of the FTP server (required)

        :return: The host of this FtpInput.
        :rtype: string_types
        """
        return self._host

    @host.setter
    def host(self, host):
        # type: (string_types) -> None
        """Sets the host of this FtpInput.

        Host URL or IP of the FTP server (required)

        :param host: The host of this FtpInput.
        :type: string_types
        """

        if host is not None:
            if not isinstance(host, string_types):
                raise TypeError("Invalid type for `host`, type has to be `string_types`")

        self._host = host

    @property
    def port(self):
        # type: () -> int
        """Gets the port of this FtpInput.

        Port to use, standard for FTP: 21

        :return: The port of this FtpInput.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        # type: (int) -> None
        """Sets the port of this FtpInput.

        Port to use, standard for FTP: 21

        :param port: The port of this FtpInput.
        :type: int
        """

        if port is not None:
            if not isinstance(port, int):
                raise TypeError("Invalid type for `port`, type has to be `int`")

        self._port = port

    @property
    def passive(self):
        # type: () -> bool
        """Gets the passive of this FtpInput.

        Use passive mode. Default is true.

        :return: The passive of this FtpInput.
        :rtype: bool
        """
        return self._passive

    @passive.setter
    def passive(self, passive):
        # type: (bool) -> None
        """Sets the passive of this FtpInput.

        Use passive mode. Default is true.

        :param passive: The passive of this FtpInput.
        :type: bool
        """

        if passive is not None:
            if not isinstance(passive, bool):
                raise TypeError("Invalid type for `passive`, type has to be `bool`")

        self._passive = passive

    @property
    def username(self):
        # type: () -> string_types
        """Gets the username of this FtpInput.

        Your FTP Username

        :return: The username of this FtpInput.
        :rtype: string_types
        """
        return self._username

    @username.setter
    def username(self, username):
        # type: (string_types) -> None
        """Sets the username of this FtpInput.

        Your FTP Username

        :param username: The username of this FtpInput.
        :type: string_types
        """

        if username is not None:
            if not isinstance(username, string_types):
                raise TypeError("Invalid type for `username`, type has to be `string_types`")

        self._username = username

    @property
    def password(self):
        # type: () -> string_types
        """Gets the password of this FtpInput.

        Your FTP password

        :return: The password of this FtpInput.
        :rtype: string_types
        """
        return self._password

    @password.setter
    def password(self, password):
        # type: (string_types) -> None
        """Sets the password of this FtpInput.

        Your FTP password

        :param password: The password of this FtpInput.
        :type: string_types
        """

        if password is not None:
            if not isinstance(password, string_types):
                raise TypeError("Invalid type for `password`, type has to be `string_types`")

        self._password = password

    @property
    def remote_verification_enabled(self):
        # type: () -> bool
        """Gets the remote_verification_enabled of this FtpInput.

        Ensure that connections originate from the declared ftp host. Default is true.

        :return: The remote_verification_enabled of this FtpInput.
        :rtype: bool
        """
        return self._remote_verification_enabled

    @remote_verification_enabled.setter
    def remote_verification_enabled(self, remote_verification_enabled):
        # type: (bool) -> None
        """Sets the remote_verification_enabled of this FtpInput.

        Ensure that connections originate from the declared ftp host. Default is true.

        :param remote_verification_enabled: The remote_verification_enabled of this FtpInput.
        :type: bool
        """

        if remote_verification_enabled is not None:
            if not isinstance(remote_verification_enabled, bool):
                raise TypeError("Invalid type for `remote_verification_enabled`, type has to be `bool`")

        self._remote_verification_enabled = remote_verification_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(FtpInput, self), "to_dict"):
            result = super(FtpInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FtpInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
